@@ -46,4 +46,7 @@ String *backupRegExp(BackupRegExpParam param);
 BackupType backupType(const String *type);
 const String *backupTypeStr(BackupType type);
 
+// Create a symlink to the specified backup (if symlinks are supported)
+void backupLinkLatest(const String *backupLabel);
+
 #endif
