@@ -81,7 +81,7 @@ checkStandby(const DbGetResult dbGroup, unsigned int pgPathDefinedTotal)
         // Check that the backup and archive info files exist and are valid for the current database of the stanza
         checkStanzaInfoPg(
             storageRepo(), pgControl.version, pgControl.systemId, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-            cfgOptionStr(cfgOptRepoCipherPass));
+            cfgOptionStrNull(cfgOptRepoCipherPass));
 
         LOG_INFO("switch wal not performed because this is a standby");
 
@@ -119,12 +119,12 @@ checkPrimary(const DbGetResult dbGroup)
         // Check that the backup and archive info files exist and are valid for the current database of the stanza
         checkStanzaInfoPg(
             storageRepo(), pgControl.version, pgControl.systemId, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-            cfgOptionStr(cfgOptRepoCipherPass));
+            cfgOptionStrNull(cfgOptRepoCipherPass));
 
         // Attempt to load the archive info file and retrieve the archiveId
         InfoArchive *archiveInfo = infoArchiveLoadFile(
             storageRepo(), INFO_ARCHIVE_PATH_FILE_STR, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-            cfgOptionStr(cfgOptRepoCipherPass));
+            cfgOptionStrNull(cfgOptRepoCipherPass));
         const String *archiveId = infoArchiveId(archiveInfo);
 
         // Perform a WAL switch
