@@ -5,6 +5,8 @@ Expire Command
 
 #include "command/archive/common.h"
 #include "command/backup/common.h"
+#include "command/control/common.h"
+#include "common/time.h"
 #include "common/type/list.h"
 #include "common/debug.h"
 #include "common/regExp.h"
@@ -12,6 +14,7 @@ Expire Command
 #include "info/infoArchive.h"
 #include "info/infoBackup.h"
 #include "info/manifest.h"
+#include "protocol/helper.h"
 #include "storage/helper.h"
 
 #include <stdlib.h>
@@ -95,6 +98,93 @@ expireBackup(InfoBackup *infoBackup, const String *backupLabel)
     FUNCTION_LOG_RETURN(STRING_LIST, result);
 }
 
+/***********************************************************************************************************************************
+Function to expire a selected backup (and all its dependents) regardless of retention rules.
+***********************************************************************************************************************************/
+static unsigned int
+expireAdhocBackup(InfoBackup *infoBackup, const String *backupLabel)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
+        FUNCTION_LOG_PARAM(STRING, backupLabel);
+    FUNCTION_LOG_END();
+
+    ASSERT(infoBackup != NULL);
+    ASSERT(backupLabel != NULL);
+
+    unsigned int result = 0;
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // If the label format is invalid, then error
+        if (!regExpMatchOne(backupRegExpP(.full = true, .differential = true, .incremental = true), backupLabel))
+        {
+            THROW_FMT(OptionInvalidValueError, "'%s' is not a valid backup label format", strPtr(backupLabel));
+        }
+
+        // If the label is not a current backup then notify user and exit
+        if (infoBackupDataByLabel(infoBackup, backupLabel) == NULL)
+        {
+            LOG_WARN_FMT(
+                "backup %s does not exist\nHINT: run the info command and confirm the backup is listed", strPtr(backupLabel));
+        }
+        else
+        {
+            // Get a list of all full backups with most recent in position 0
+            StringList *fullList = strLstSort(infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true)), sortOrderDesc);
+
+            // If the requested backup to expire is the latest full backup
+            if (strCmp(strLstGet(fullList, 0), backupLabel) == 0)
+            {
+                // If the latest full backup requested is the only backup or the prior full backup is not for the same db-id
+                // then the backup requested cannot be expired
+                if (strLstSize(fullList) == 1 || infoBackupDataByLabel(infoBackup, backupLabel)->backupPgId !=
+                    infoBackupDataByLabel(infoBackup, strLstGet(fullList, 1))->backupPgId)
+                {
+                    THROW_FMT(
+                        BackupSetInvalidError, "full backup %s cannot be expired until another full backup has been created",
+                        strPtr(backupLabel));
+                }
+            }
+
+            // Save off what is currently the latest backup (it may be removed if it is the adhoc backup or is a dependent of the
+            // adhoc backup
+            const String *latestBackup = infoBackupData(infoBackup, infoBackupDataTotal(infoBackup) - 1).backupLabel;
+
+            // Expire the requested backup and any dependents
+            StringList *backupExpired = expireBackup(infoBackup, backupLabel);
+
+            // If the latest backup was removed, then update the latest link if not a dry-run
+            if (infoBackupDataByLabel(infoBackup, latestBackup) == NULL)
+            {
+                // If retention settings have been configured, then there may be holes in the archives. For example, if the archive
+                // for db-id=1 has 01,02,03,04,05 and F1 backup has archive start-stop 02-03 and rentention-full=1
+                // (hence retention-archive=1 and retention-archive-type=full), then when F2 backup is created and assuming its
+                // archive start-stop=05-06 then archives 01 and 04 will be removed resulting in F1 not being able to play through
+                // PITR, which is expected. Now adhoc expire is attempted on F2 - it will be allowed but now there will be no
+                // backups that can be recovered through PITR until the next full backup is created. Same problem for differential
+                // backups with retention-diff.
+                LOG_WARN_FMT(
+                    "expiring latest backup %s - the ability to perform point-in-time-recovery (PITR) may be affected\n"
+                    "HINT: non-default settings for '%s'/'%s' (even in prior expires) can cause gaps in the WAL.",
+                    strPtr(latestBackup), cfgOptionName(cfgOptRepoRetentionArchive), cfgOptionName(cfgOptRepoRetentionArchiveType));
+
+                // Adhoc expire is never performed through backup command so only check to determine if dry-run has been set or not
+                if (!cfgOptionBool(cfgOptDryRun))
+                    backupLinkLatest(infoBackupData(infoBackup, infoBackupDataTotal(infoBackup) - 1).backupLabel);
+            }
+
+            result = strLstSize(backupExpired);
+
+            // Log the expired backup list (prepend "set:" if there were any dependents that were also expired)
+            LOG_INFO_FMT("expire adhoc backup %s%s", (result > 1 ? "set: " : ""), strPtr(strLstJoin(backupExpired, ", ")));
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN(UINT, result);
+}
+
 /***********************************************************************************************************************************
 Expire differential backups
 ***********************************************************************************************************************************/
@@ -196,6 +286,80 @@ expireFullBackup(InfoBackup *infoBackup)
     FUNCTION_LOG_RETURN(UINT, result);
 }
 
+/***********************************************************************************************************************************
+Expire backups based on time
+***********************************************************************************************************************************/
+static unsigned int
+expireTimeBasedBackup(InfoBackup *infoBackup, const time_t minTimestamp)
+{
+    FUNCTION_LOG_BEGIN(logLevelDebug);
+        FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
+        FUNCTION_LOG_PARAM(TIME, minTimestamp);
+    FUNCTION_LOG_END();
+
+    ASSERT(infoBackup != NULL);
+    ASSERT(minTimestamp > 0);
+
+    unsigned int result = 0;
+
+    MEM_CONTEXT_TEMP_BEGIN()
+    {
+        // Get the list of full backups
+        StringList *currentBackupList = strLstSort(infoBackupDataLabelList(infoBackup, backupRegExpP(.full = true)), sortOrderAsc);
+        unsigned int backupIdx = strLstSize(currentBackupList);
+
+        // Find out the point where we will have to stop purging backups. Starting with the newest backup (the end of the list),
+        // find the first backup that is older than the expire time period by checking the backup stop time. This way, if the
+        // backups are F1 D1a D1b D1c F2 D2a D2b F3 D3a D3b and the expiration time period is at D2b, then purge only F1, D1a, D1b
+        // and D1c, and keep the next full backups (F2 and F3) and all intermediate non-full backups.
+        if (backupIdx > 0)
+        {
+            const String *lastBackupLabelToKeep = NULL;
+
+            do
+            {
+                backupIdx--;
+
+                InfoBackupData *info = infoBackupDataByLabel(infoBackup, strLstGet(currentBackupList, backupIdx));
+                lastBackupLabelToKeep = info->backupLabel;
+
+                // We can start deleting before this backup. This way, we keep one full backup and its dependents.
+                if (info->backupTimestampStop < minTimestamp)
+                    break;
+            }
+            while (backupIdx != 0);
+
+            // Count number of full backups being expired
+            unsigned int numFullExpired = 0;
+
+            // Since expireBackup will remove the requested entry from the backup list, we keep checking the first entry which is
+            // always the oldest so if it is not the backup to keep then we can remove it
+            while (!strEq(infoBackupData(infoBackup, 0).backupLabel, lastBackupLabelToKeep))
+            {
+                StringList *backupExpired = expireBackup(infoBackup, infoBackupData(infoBackup, 0).backupLabel);
+
+                result += strLstSize(backupExpired);
+                numFullExpired++;
+
+                // Log the expired backups. If there is more than one backup, then prepend "set:"
+                LOG_INFO_FMT(
+                    "expire time-based backup %s%s", (strLstSize(backupExpired) > 1 ? "set: " : ""),
+                    strPtr(strLstJoin(backupExpired, ", ")));
+            }
+
+            if (strEqZ(cfgOptionStr(cfgOptRepoRetentionArchiveType), CFGOPTVAL_TMP_REPO_RETENTION_ARCHIVE_TYPE_FULL) &&
+                !cfgOptionTest(cfgOptRepoRetentionArchive) && numFullExpired > 0)
+            {
+                cfgOptionSet(
+                    cfgOptRepoRetentionArchive, cfgSourceDefault, varNewUInt(strLstSize(currentBackupList) - numFullExpired));
+            }
+        }
+    }
+    MEM_CONTEXT_TEMP_END();
+
+    FUNCTION_LOG_RETURN(UINT, result);
+}
+
 /***********************************************************************************************************************************
 Log detailed information about archive logs removed
 ***********************************************************************************************************************************/
@@ -217,10 +381,11 @@ logExpire(ArchiveExpired *archiveExpire, String *archiveId)
 Process archive retention
 ***********************************************************************************************************************************/
 static void
-removeExpiredArchive(InfoBackup *infoBackup)
+removeExpiredArchive(InfoBackup *infoBackup, bool timeBasedFullRetention)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
+        FUNCTION_LOG_PARAM(BOOL, timeBasedFullRetention);
     FUNCTION_LOG_END();
 
     ASSERT(infoBackup != NULL);
@@ -235,7 +400,13 @@ removeExpiredArchive(InfoBackup *infoBackup)
         // cfgLoadUpdateOption based on certain rules.
         if (archiveRetention == 0)
         {
-             LOG_INFO_FMT("option '%s' is not set - archive logs will not be expired", cfgOptionName(cfgOptRepoRetentionArchive));
+            String *msg = strNew("- archive logs will not be expired");
+
+            // Only notify user if not time-based retention
+            if (!timeBasedFullRetention)
+                LOG_INFO_FMT("option '%s' is not set %s", cfgOptionName(cfgOptRepoRetentionArchive), strPtr(msg));
+            else
+                LOG_INFO_FMT("time-based archive retention not met %s", strPtr(msg));
         }
         else
         {
@@ -260,13 +431,14 @@ removeExpiredArchive(InfoBackup *infoBackup)
                     sortOrderDesc);
             }
 
-            // Expire archives. If no backups were found then preserve current archive logs - too soon to expire them.
-            if (strLstSize(globalBackupRetentionList) > 0)
+            // Expire archives. If no backups were found or the number of backups found is not enough to satify archive retention
+            // then preserve current archive logs - too soon to expire them.
+            if (strLstSize(globalBackupRetentionList) > 0 && archiveRetention <= strLstSize(globalBackupRetentionList))
             {
                 // Attempt to load the archive info file
                 InfoArchive *infoArchive = infoArchiveLoadFile(
                     storageRepo(), INFO_ARCHIVE_PATH_FILE_STR, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-                    cfgOptionStr(cfgOptRepoCipherPass));
+                    cfgOptionStrNull(cfgOptRepoCipherPass));
 
                 InfoPg *infoArchivePgData = infoArchivePg(infoArchive);
 
@@ -371,37 +543,21 @@ removeExpiredArchive(InfoBackup *infoBackup)
                         // If we get here, then a local backup was found for retention
                         StringList *localBackupArchiveRetentionList = strLstNew();
 
-                        // If the archive retention is less than or equal to the number of all backups, then perform selective
-                        // expiration
-                        if (archiveRetention <= strLstSize(globalBackupRetentionList))
+                        // From the full list of backups in archive retention, find the intersection of local backups to retain
+                        // from oldest to newest
+                        for (unsigned int globalIdx = strLstSize(globalBackupArchiveRetentionList) - 1;
+                             (int)globalIdx >= 0; globalIdx--)
                         {
-                            // From the full list of backups in archive retention, find the intersection of local backups to retain
-                            // from oldest to newest
-                            for (unsigned int globalIdx = strLstSize(globalBackupArchiveRetentionList) - 1;
-                                 (int)globalIdx >= 0; globalIdx--)
+                            for (unsigned int localIdx = 0; localIdx < strLstSize(localBackupRetentionList); localIdx++)
                             {
-                                for (unsigned int localIdx = 0; localIdx < strLstSize(localBackupRetentionList); localIdx++)
+                                if (strCmp(
+                                        strLstGet(globalBackupArchiveRetentionList, globalIdx),
+                                        strLstGet(localBackupRetentionList, localIdx)) == 0)
                                 {
-                                    if (strCmp(
-                                            strLstGet(globalBackupArchiveRetentionList, globalIdx),
-                                            strLstGet(localBackupRetentionList, localIdx)) == 0)
-                                    {
-                                        strLstAdd(localBackupArchiveRetentionList, strLstGet(localBackupRetentionList, localIdx));
-                                    }
+                                    strLstAdd(localBackupArchiveRetentionList, strLstGet(localBackupRetentionList, localIdx));
                                 }
                             }
                         }
-                        // Else if there are not enough backups yet globally to start archive expiration then set the archive
-                        // retention to the oldest backup so anything prior to that will be removed as it is not needed but
-                        // everything else is. This is incase there are old archives left around so that they don't stay around
-                        // forever.
-                        else
-                        {
-                            LOG_INFO_FMT(
-                                "full backup total < %u - using oldest full backup for %s archive retention", archiveRetention,
-                                strPtr(archiveId));
-                            strLstAdd(localBackupArchiveRetentionList, strLstGet(localBackupRetentionList, 0));
-                        }
 
                         // If no local backups were found as part of retention then set the backup archive retention to the newest
                         // backup so that the database is fully recoverable (can be recovered from the last backup through pitr)
@@ -598,24 +754,59 @@ removeExpiredArchive(InfoBackup *infoBackup)
 Remove expired backups from repo
 ***********************************************************************************************************************************/
 static void
-removeExpiredBackup(InfoBackup *infoBackup)
+removeExpiredBackup(InfoBackup *infoBackup, const String *adhocBackupLabel)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(INFO_BACKUP, infoBackup);
+        FUNCTION_LOG_PARAM(STRING, adhocBackupLabel);
     FUNCTION_LOG_END();
 
     ASSERT(infoBackup != NULL);
 
-    // Get all the current backups in backup.info
+    // Get all the current backups in backup.info - these will not be expired
     StringList *currentBackupList = strLstSort(infoBackupDataLabelList(infoBackup, NULL), sortOrderDesc);
+
+    // Get all the backups on disk
     StringList *backupList = strLstSort(
         storageListP(
             storageRepo(), STORAGE_REPO_BACKUP_STR,
             .expression = backupRegExpP(.full = true, .differential = true, .incremental = true)),
         sortOrderDesc);
 
+    // Initialize the index to the lastest backup on disk
+    unsigned int backupIdx = 0;
+
+    // Only remove the resumable backup if there is a possibility it is a dependent of the adhoc label being expired
+    if (adhocBackupLabel != NULL)
+    {
+        String *manifestFileName = strNewFmt(
+            STORAGE_REPO_BACKUP "/%s/" BACKUP_MANIFEST_FILE, strPtr(strLstGet(backupList, backupIdx)));
+        String *manifestCopyFileName = strNewFmt("%s" INFO_COPY_EXT, strPtr(manifestFileName));
+
+        // If the latest backup is resumable (has a backup.manifest.copy but no backup.manifest)
+        if (!storageExistsP(storageRepo(), manifestFileName) && storageExistsP(storageRepo(), manifestCopyFileName))
+        {
+            // If the resumable backup is not related to the expired adhoc backup then don't remove it
+            if (!strBeginsWith(strLstGet(backupList, backupIdx), strSubN(adhocBackupLabel, 0, 16)))
+            {
+                backupIdx = 1;
+            }
+            // Else it may be related to the adhoc backup so check if its ancestor still exists
+            else
+            {
+                Manifest *manifestResume = manifestLoadFile(
+                    storageRepo(), manifestFileName, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
+                    infoPgCipherPass(infoBackupPg(infoBackup)));
+
+                // If the ancestor of the resumable backup still exists in backup.info then do not remove the resumable backup
+                if (infoBackupDataByLabel(infoBackup, manifestData(manifestResume)->backupLabelPrior) != NULL)
+                    backupIdx = 1;
+            }
+        }
+    }
+
     // Remove non-current backups from disk
-    for (unsigned int backupIdx = 0; backupIdx < strLstSize(backupList); backupIdx++)
+    for (; backupIdx < strLstSize(backupList); backupIdx++)
     {
         if (!strLstExists(currentBackupList, strLstGet(backupList, backupIdx)))
         {
@@ -640,29 +831,56 @@ cmdExpire(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
 
+    // Verify the repo is local
+    repoIsLocalVerify();
+
+    // Test for stop file
+    lockStopTest();
+
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        // Get the repo storage in case it is remote and encryption settings need to be pulled down
-        storageRepo();
-
         // Load the backup.info
         InfoBackup *infoBackup = infoBackupLoadFileReconstruct(
             storageRepo(), INFO_BACKUP_PATH_FILE_STR, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-            cfgOptionStr(cfgOptRepoCipherPass));
+            cfgOptionStrNull(cfgOptRepoCipherPass));
 
-        expireFullBackup(infoBackup);
-        expireDiffBackup(infoBackup);
+        const String *adhocBackupLabel = NULL;
+        bool timeBasedFullRetention = strEqZ(
+            cfgOptionStr(cfgOptRepoRetentionFullType), CFGOPTVAL_TMP_REPO_RETENTION_FULL_TYPE_TIME);
+
+        // If the --set option is valid (i.e. expire is called on its own) and is set then attempt to expire the requested backup
+        if (cfgOptionTest(cfgOptSet))
+        {
+            adhocBackupLabel = cfgOptionStr(cfgOptSet);
+            expireAdhocBackup(infoBackup, adhocBackupLabel);
+        }
+        else
+        {
+            // If time-based retention for full backups is set, then expire based on time period
+            if (timeBasedFullRetention)
+            {
+                // If a time period was provided then run time-based expiration otherwise do nothing (the user has already been
+                // warned by the config system that retention-full was not set)
+                if (cfgOptionTest(cfgOptRepoRetentionFull))
+                    expireTimeBasedBackup(infoBackup, time(NULL) - (time_t)(cfgOptionUInt(cfgOptRepoRetentionFull) * SEC_PER_DAY));
+            }
+            else
+                expireFullBackup(infoBackup);
+
+            expireDiffBackup(infoBackup);
+        }
 
         // Store the new backup info only if the dry-run mode is disabled
         if (!cfgOptionValid(cfgOptDryRun) || !cfgOptionBool(cfgOptDryRun))
         {
             infoBackupSaveFile(
                 infoBackup, storageRepoWrite(), INFO_BACKUP_PATH_FILE_STR, cipherType(cfgOptionStr(cfgOptRepoCipherType)),
-                cfgOptionStr(cfgOptRepoCipherPass));
+                cfgOptionStrNull(cfgOptRepoCipherPass));
         }
 
-        removeExpiredBackup(infoBackup);
-        removeExpiredArchive(infoBackup);
+        // Remove all files on disk that are now expired
+        removeExpiredBackup(infoBackup, adhocBackupLabel);
+        removeExpiredArchive(infoBackup, timeBasedFullRetention);
     }
     MEM_CONTEXT_TEMP_END();
 
