@@ -25,14 +25,16 @@ STRING_EXTERN(HTTP_VERB_HEAD_STR,                                   HTTP_VERB_HE
 STRING_EXTERN(HTTP_VERB_POST_STR,                                   HTTP_VERB_POST);
 STRING_EXTERN(HTTP_VERB_PUT_STR,                                    HTTP_VERB_PUT);
 
+STRING_EXTERN(HTTP_HEADER_AUTHORIZATION_STR,                        HTTP_HEADER_AUTHORIZATION);
 #define HTTP_HEADER_CONNECTION                                      "connection"
     STRING_STATIC(HTTP_HEADER_CONNECTION_STR,                       HTTP_HEADER_CONNECTION);
 STRING_EXTERN(HTTP_HEADER_CONTENT_LENGTH_STR,                       HTTP_HEADER_CONTENT_LENGTH);
 STRING_EXTERN(HTTP_HEADER_CONTENT_MD5_STR,                          HTTP_HEADER_CONTENT_MD5);
+STRING_EXTERN(HTTP_HEADER_ETAG_STR,                                 HTTP_HEADER_ETAG);
+STRING_EXTERN(HTTP_HEADER_HOST_STR,                                 HTTP_HEADER_HOST);
+STRING_EXTERN(HTTP_HEADER_LAST_MODIFIED_STR,                        HTTP_HEADER_LAST_MODIFIED);
 #define HTTP_HEADER_TRANSFER_ENCODING                               "transfer-encoding"
     STRING_STATIC(HTTP_HEADER_TRANSFER_ENCODING_STR,                HTTP_HEADER_TRANSFER_ENCODING);
-STRING_EXTERN(HTTP_HEADER_ETAG_STR,                                 HTTP_HEADER_ETAG);
-STRING_EXTERN(HTTP_HEADER_LAST_MODIFIED_STR,                        HTTP_HEADER_LAST_MODIFIED);
 
 #define HTTP_VALUE_CONNECTION_CLOSE                                 "close"
     STRING_STATIC(HTTP_VALUE_CONNECTION_CLOSE_STR,                  HTTP_VALUE_CONNECTION_CLOSE);
@@ -248,7 +250,6 @@ httpClientRequest(
 
     MEM_CONTEXT_TEMP_BEGIN()
     {
-        bool complete = false;
         bool retry;
         Wait *wait = waitNew(this->timeout);
 
@@ -319,13 +320,13 @@ httpClientRequest(
                 ioWriteFlush(tlsSessionIoWrite(this->tlsSession));
 
                 // Read status and make sure it starts with the correct http version
-                String *status = strTrim(ioReadLine(tlsSessionIoRead(this->tlsSession)));
+                String *status = ioReadLine(tlsSessionIoRead(this->tlsSession));
 
                 if (!strBeginsWith(status, HTTP_VERSION_STR))
-                    THROW_FMT(FormatError, "http version of response '%s' must be " HTTP_VERSION, strPtr(status));
+                    THROW_FMT(FormatError, "http version of response '%s' must be " HTTP_VERSION, strPtr(strTrim(status)));
 
-                // Now read the response code and message
-                status = strSub(status, sizeof(HTTP_VERSION));
+                // Now read the response code and message (and strip the trailing CR)
+                status = strSubN(status, sizeof(HTTP_VERSION), strSize(status) - sizeof(HTTP_VERSION) - 1);
 
                 int spacePos = strChr(status, ' ');
 
@@ -451,12 +452,12 @@ httpClientRequest(
                 // and choose errors in this class to retry.
                 if (httpClientResponseCode(this) / 100 == HTTP_RESPONSE_CODE_RETRY_CLASS)
                     THROW_FMT(ServiceError, "[%u] %s", httpClientResponseCode(this), strPtr(httpClientResponseMessage(this)));
-
-                // Request was successful
-                complete = true;
             }
             CATCH_ANY()
             {
+                tlsSessionFree(this->tlsSession);
+                this->tlsSession = NULL;
+
                 // Retry if wait time has not expired
                 if (waitMore(wait))
                 {
@@ -465,16 +466,12 @@ httpClientRequest(
 
                     httpClientStatLocal.retry++;
                 }
-
-                tlsSessionFree(this->tlsSession);
-                this->tlsSession = NULL;
+                else
+                    RETHROW();
             }
             TRY_END();
         }
-        while (!complete && retry);
-
-        if (!complete)
-            RETHROW();
+        while (retry);
 
         // Move the result buffer (if any) to the parent context
         bufMove(result, memContextPrior());
