@@ -410,8 +410,6 @@ cfgFileLoad(                                                        // NOTE: Pas
 }
 
 /***********************************************************************************************************************************
-Parse the command-line arguments and config file to produce final config data
-
 ??? Add validation of section names and check all sections for invalid options in the check command.  It's too expensive to add the
 logic to this critical path code.
 ***********************************************************************************************************************************/
@@ -615,7 +613,7 @@ configParse(unsigned int argListSize, const char *argList[], bool resetLogLevel)
 
         // Enable logging (except for local and remote commands) so config file warnings will be output
         if (cfgCommandRole() != cfgCmdRoleLocal && cfgCommandRole() != cfgCmdRoleRemote && resetLogLevel)
-            logInit(logLevelWarn, logLevelWarn, logLevelOff, false, 1, false);
+            logInit(logLevelWarn, logLevelWarn, logLevelOff, false, 0, 1, false);
 
         // Only continue if command options need to be validated, i.e. a real command is running or we are getting help for a
         // specific command and would like to display actual option values in the help.
