@@ -1,21 +1,21 @@
 /***********************************************************************************************************************************
 PostgreSQL Version Interface
 
-Macros for building version-specific functions that interface with the types in version.auto.h.  Due to the way PostgreSQL types
+Macros for building version-specific functions that interface with the types in version.vendor.h.  Due to the way PostgreSQL types
 evolve over time, this seems to be the easiest way to extract information from them.
 
 These macros should be kept as simple as possible, with most of the logic contained in postgres/interface.c.
 
 Each version of PostgreSQL will need a vXXX.c file to contain the version-specific functions created by these macros.
 ***********************************************************************************************************************************/
-#ifndef POSTGRES_INTERFACE_IMPLEMENTATION_H
-#define POSTGRES_INTERFACE_IMPLEMENTATION_H
+#ifndef POSTGRES_INTERFACE_VERSIONINTERN_H
+#define POSTGRES_INTERFACE_VERSIONINTERN_H
 
 #include "common/debug.h"
 #include "postgres/interface/version.h"
 #include "postgres/version.h"
 
-#include "postgres/interface/version.auto.h"
+#include "postgres/interface/version.vendor.h"
 
 /***********************************************************************************************************************************
 Get the catalog version
@@ -124,12 +124,15 @@ Create a pg_control file for testing
     {                                                                                                                              \
         ASSERT(buffer != NULL);                                                                                                    \
                                                                                                                                    \
-        ((ControlFileData *)buffer)->system_identifier = pgControl.systemId;                                                       \
-        ((ControlFileData *)buffer)->pg_control_version = PG_CONTROL_VERSION;                                                      \
-        ((ControlFileData *)buffer)->catalog_version_no = CATALOG_VERSION_NO;                                                      \
-        ((ControlFileData *)buffer)->blcksz = pgControl.pageSize;                                                                  \
-        ((ControlFileData *)buffer)->xlog_seg_size = pgControl.walSegmentSize;                                                     \
-        ((ControlFileData *)buffer)->data_checksum_version = pgControl.pageChecksum;                                               \
+        *(ControlFileData *)buffer = (ControlFileData)                                                                             \
+        {                                                                                                                          \
+            .system_identifier = pgControl.systemId,                                                                               \
+            .pg_control_version = PG_CONTROL_VERSION,                                                                              \
+            .catalog_version_no = CATALOG_VERSION_NO,                                                                              \
+            .blcksz = pgControl.pageSize,                                                                                          \
+            .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
+            .data_checksum_version = pgControl.pageChecksum,                                                                       \
+        };                                                                                                                         \
     }
 
 #elif PG_VERSION >= PG_VERSION_83
@@ -141,11 +144,14 @@ Create a pg_control file for testing
         ASSERT(buffer != NULL);                                                                                                    \
         ASSERT(!pgControl.pageChecksum);                                                                                           \
                                                                                                                                    \
-        ((ControlFileData *)buffer)->system_identifier = pgControl.systemId;                                                       \
-        ((ControlFileData *)buffer)->pg_control_version = PG_CONTROL_VERSION;                                                      \
-        ((ControlFileData *)buffer)->catalog_version_no = CATALOG_VERSION_NO;                                                      \
-        ((ControlFileData *)buffer)->blcksz = pgControl.pageSize;                                                                  \
-        ((ControlFileData *)buffer)->xlog_seg_size = pgControl.walSegmentSize;                                                     \
+        *(ControlFileData *)buffer = (ControlFileData)                                                                             \
+        {                                                                                                                          \
+            .system_identifier = pgControl.systemId,                                                                               \
+            .pg_control_version = PG_CONTROL_VERSION,                                                                              \
+            .catalog_version_no = CATALOG_VERSION_NO,                                                                              \
+            .blcksz = pgControl.pageSize,                                                                                          \
+            .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
+        };                                                                                                                         \
     }
 
 #endif
