@@ -106,12 +106,12 @@ storageHelperStanzaInit(const bool stanzaRequired)
     // If the stanza is NULL and the storage has not already been initialized then initialize the stanza
     if (!storageHelper.stanzaInit)
     {
-        if (stanzaRequired && cfgOptionStr(cfgOptStanza) == NULL)
+        if (stanzaRequired && cfgOptionStrNull(cfgOptStanza) == NULL)
             THROW(AssertError, "stanza cannot be NULL for this storage object");
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.stanza = strDup(cfgOptionStr(cfgOptStanza));
+            storageHelper.stanza = strDup(cfgOptionStrNull(cfgOptStanza));
             storageHelper.stanzaInit = true;
         }
         MEM_CONTEXT_END();
@@ -132,8 +132,7 @@ storageLocal(void)
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.storageLocal =  storagePosixNew(
-                FSLASH_STR, STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false, NULL);
+            storageHelper.storageLocal =  storagePosixNewP(FSLASH_STR);
         }
         MEM_CONTEXT_END();
     }
@@ -152,8 +151,7 @@ storageLocalWrite(void)
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.storageLocalWrite = storagePosixNew(
-                FSLASH_STR, STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL);
+            storageHelper.storageLocalWrite = storagePosixNewP(FSLASH_STR, .write = true);
         }
         MEM_CONTEXT_END();
     }
@@ -184,8 +182,7 @@ storagePgGet(unsigned int hostId, bool write)
     // Use Posix storage
     else
     {
-        result = storagePosixNew(
-            cfgOptionStr(cfgOptPgPath + hostId - 1), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, write, NULL);
+        result = storagePosixNewP(cfgOptionStr(cfgOptPgPath + hostId - 1), .write = write);
     }
 
     FUNCTION_TEST_RETURN(result);
@@ -362,8 +359,8 @@ storageRepoGet(const String *type, bool write)
     // Use Posix storage
     else if (strEqZ(type, STORAGE_TYPE_POSIX))
     {
-        result = storagePosixNew(
-            cfgOptionStr(cfgOptRepoPath), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, write, storageRepoPathExpression);
+        result = storagePosixNewP(
+            cfgOptionStr(cfgOptRepoPath), .write = write, .pathExpressionFunction = storageRepoPathExpression);
     }
     // Use S3 storage
     else if (strEqZ(type, STORAGE_TYPE_S3))
@@ -383,10 +380,8 @@ storageRepoGet(const String *type, bool write)
             cfgOptionStr(cfgOptRepoPath), write, storageRepoPathExpression, cfgOptionStr(cfgOptRepoS3Bucket), endPoint,
             strEqZ(cfgOptionStr(cfgOptRepoS3UriStyle), STORAGE_S3_URI_STYLE_HOST) ? storageS3UriStyleHost : storageS3UriStylePath,
             cfgOptionStr(cfgOptRepoS3Region), cfgOptionStr(cfgOptRepoS3Key), cfgOptionStr(cfgOptRepoS3KeySecret),
-            cfgOptionTest(cfgOptRepoS3Token) ? cfgOptionStr(cfgOptRepoS3Token) : NULL, STORAGE_S3_PARTSIZE_MIN,
-            STORAGE_S3_DELETE_MAX, host, port, ioTimeoutMs(), cfgOptionBool(cfgOptRepoS3VerifyTls),
-            cfgOptionTest(cfgOptRepoS3CaFile) ? cfgOptionStr(cfgOptRepoS3CaFile) : NULL,
-            cfgOptionTest(cfgOptRepoS3CaPath) ? cfgOptionStr(cfgOptRepoS3CaPath) : NULL);
+            cfgOptionStrNull(cfgOptRepoS3Token), STORAGE_S3_PARTSIZE_MIN, STORAGE_S3_DELETE_MAX, host, port, ioTimeoutMs(),
+            cfgOptionBool(cfgOptRepoS3VerifyTls), cfgOptionStrNull(cfgOptRepoS3CaFile), cfgOptionStrNull(cfgOptRepoS3CaPath));
     }
     else
         THROW_FMT(AssertError, "invalid storage type '%s'", strPtr(type));
@@ -490,9 +485,8 @@ storageSpool(void)
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.storageSpool = storagePosixNew(
-                cfgOptionStr(cfgOptSpoolPath), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false,
-                storageSpoolPathExpression);
+            storageHelper.storageSpool = storagePosixNewP(
+                cfgOptionStr(cfgOptSpoolPath), .pathExpressionFunction = storageSpoolPathExpression);
         }
         MEM_CONTEXT_END();
     }
@@ -516,9 +510,8 @@ storageSpoolWrite(void)
 
         MEM_CONTEXT_BEGIN(storageHelper.memContext)
         {
-            storageHelper.storageSpoolWrite = storagePosixNew(
-                cfgOptionStr(cfgOptSpoolPath), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true,
-                storageSpoolPathExpression);
+            storageHelper.storageSpoolWrite = storagePosixNewP(
+                cfgOptionStr(cfgOptSpoolPath), .write = true, .pathExpressionFunction = storageSpoolPathExpression);
         }
         MEM_CONTEXT_END();
     }
