@@ -252,6 +252,9 @@ sub run
 
         if ($self->{oTest}->{&TEST_C})
         {
+            # Build filename for valgrind suppressions
+            my $strValgrindSuppress = $self->{strGCovPath} . '/test/valgrind.suppress.' . $self->{oTest}->{&TEST_VM};
+
             $strCommand =
                 ($self->{oTest}->{&TEST_VM} ne VM_NONE  ? 'docker exec -i -u ' . TEST_USER . " ${strImage} " : '') .
                 "bash -l -c '" .
@@ -259,9 +262,11 @@ sub run
                 # Remove coverage data from last run
                 "rm -f test.gcda && " .
                 "make -j $self->{iBuildMax} -s 2>&1 &&" .
+                # Test with valgrind when requested
                 ($self->{oTest}->{&TEST_VM} ne VM_CO6 && $self->{bValgrindUnit} &&
                     $self->{oTest}->{&TEST_TYPE} ne TESTDEF_PERFORMANCE ?
-                    " valgrind -q --gen-suppressions=all --suppressions=$self->{strGCovPath}/test/valgrind.suppress" .
+                    ' valgrind -q --gen-suppressions=all ' .
+                    ($self->{oStorageTest}->exists($strValgrindSuppress) ? " --suppressions=${strValgrindSuppress}" : '') .
                     " --leak-check=full --leak-resolution=high --error-exitcode=25" : '') .
                 " ./test.bin 2>&1'";
         }
@@ -306,6 +311,9 @@ sub run
                     # Skip all files except .c files (including .auto.c)
                     next if $strFile !~ /(?<!\.auto)\.c$/;
 
+                    # Skip all files except .c files (including .vendor.c)
+                    next if $strFile !~ /(?<!\.vendor)\.c$/;
+
                     # ??? Skip main for now until the function can be renamed to allow unit testing
                     next if $strFile =~ /main\.c$/;
 
@@ -330,9 +338,12 @@ sub run
                     # Don't include the test file as it is already included below
                     next if $strFile =~ /Test$/;
 
-                    # Don't any auto files as they are included in their companion C files
+                    # Don't include auto files as they are included in their companion C files
                     next if $strFile =~ /auto$/;
 
+                    # Don't include vendor files as they are included in regular C files
+                    next if $strFile =~ /vendor$/;
+
                     # Include the C file if it exists
                     my $strCIncludeFile = "${strFile}.c";
 
@@ -440,7 +451,8 @@ sub run
                 my $strBuildAutoH =
                     ($self->{oTest}->{&TEST_VM} ne VM_CO6 ? "#define HAVE_STATIC_ASSERT\n" : '') .
                     "#define HAVE_BUILTIN_TYPES_COMPATIBLE_P\n" .
-                    (vmWithLz4($self->{oTest}->{&TEST_VM}) ? '#define HAVE_LIBLZ4' : '') . "\n";
+                    (vmWithLz4($self->{oTest}->{&TEST_VM}) ? '#define HAVE_LIBLZ4' : '') . "\n" .
+                    (vmWithZst($self->{oTest}->{&TEST_VM}) ? '#define HAVE_LIBZST' : '') . "\n";
 
                 buildPutDiffers($self->{oStorageTest}, "$self->{strGCovPath}/" . BUILD_AUTO_H, $strBuildAutoH);
 
@@ -495,6 +507,7 @@ sub run
                     (($self->{bOptimize} && ($self->{bProfile} || $bPerformance)) ? '-O2' : $strNoOptimizeFlags) .
                     (!$self->{bDebugTestTrace} && $self->{bDebug} ? ' -DDEBUG_TEST_TRACE' : '') .
                     (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ? ' -fprofile-arcs -ftest-coverage' : '') .
+                    ($self->{oTest}->{&TEST_VM} eq VM_NONE ? '' : " -DTEST_CONTAINER_REQUIRED") .
                     ($self->{oTest}->{&TEST_CTESTDEF} ? " $self->{oTest}->{&TEST_CTESTDEF}" : '');
 
                 buildPutDiffers(
@@ -517,8 +530,9 @@ sub run
                     "BUILDFLAGS=${strBuildFlags}\n" .
                     "HARNESSFLAGS=${strHarnessFlags}\n" .
                     "TESTFLAGS=${strTestFlags}\n" .
-                    "LDFLAGS=-lcrypto -lssl -lxml2 -lz" .
+                    "LDFLAGS=-lcrypto -lssl -lxml2 -lz -lbz2" .
                         (vmWithLz4($self->{oTest}->{&TEST_VM}) ? ' -llz4' : '') .
+                        (vmWithZst($self->{oTest}->{&TEST_VM}) ? ' -lzstd' : '') .
                         (vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit} ? " -lgcov" : '') .
                         (vmWithBackTrace($self->{oTest}->{&TEST_VM}) && $self->{bBackTrace} ? ' -lbacktrace' : '') .
                     "\n" .
@@ -631,7 +645,8 @@ sub end
         if ($iExitStatus == 0 && $self->{oTest}->{&TEST_C} && vmCoverageC($self->{oTest}->{&TEST_VM}) && $self->{bCoverageUnit})
         {
             coverageExtract(
-                $self->{oStorageTest}, $self->{oTest}->{&TEST_MODULE}, $self->{oTest}->{&TEST_NAME}, $self->{bCoverageSummary},
+                $self->{oStorageTest}, $self->{oTest}->{&TEST_MODULE}, $self->{oTest}->{&TEST_NAME},
+                $self->{oTest}->{&TEST_VM} ne VM_NONE, $self->{bCoverageSummary},
                 $self->{oTest}->{&TEST_VM} eq VM_NONE ? undef : $strImage, $self->{strTestPath}, "$self->{strTestPath}/temp",
                 $self->{strGCovPath}, $self->{strBackRestBase} . '/test/result');
         }
