@@ -73,10 +73,12 @@ use constant CFGOPTVAL_BACKUP_TYPE_INCR                             => 'incr';
 use constant CFGOPTVAL_REPO_CIPHER_TYPE_AES_256_CBC                 => 'aes-256-cbc';
     push @EXPORT, qw(CFGOPTVAL_REPO_CIPHER_TYPE_AES_256_CBC);
 
-use constant STORAGE_CIFS                                           => 'cifs';
-    push @EXPORT, qw(STORAGE_CIFS);
-use constant STORAGE_S3                                             => 's3';
-    push @EXPORT, qw(STORAGE_S3);
+use constant CIFS                                                   => 'cifs';
+    push @EXPORT, qw(CIFS);
+use constant POSIX                                                  => STORAGE_POSIX;
+    push @EXPORT, qw(POSIX);
+use constant S3                                                     => 's3';
+    push @EXPORT, qw(S3);
 
 use constant CFGOPTVAL_RESTORE_TYPE_DEFAULT                         => 'default';
     push @EXPORT, qw(CFGOPTVAL_RESTORE_TYPE_DEFAULT);
@@ -95,10 +97,14 @@ use constant CFGOPTVAL_RESTORE_TYPE_XID                             => 'xid';
 
 use constant NONE                                                   => 'none';
     push @EXPORT, qw(NONE);
+use constant BZ2                                                    => 'bz2';
+    push @EXPORT, qw(BZ2);
 use constant GZ                                                     => 'gz';
     push @EXPORT, qw(GZ);
 use constant LZ4                                                    => 'lz4';
     push @EXPORT, qw(LZ4);
+use constant ZST                                                    => 'zst';
+    push @EXPORT, qw(ZST);
 
 ####################################################################################################################################
 # new
@@ -452,7 +458,7 @@ sub backupEnd
     my $strLatestLink = $self->repoBackupPath(LINK_LATEST);
     my $bLatestLinkExists = storageRepo()->exists($strLatestLink);
 
-    if ((!defined($oParam->{strRepoType}) || $oParam->{strRepoType} eq STORAGE_POSIX) && $self->hasLink())
+    if ((!defined($oParam->{strRepoType}) || $oParam->{strRepoType} eq POSIX) && $self->hasLink())
     {
         my $strLatestLinkDestination = readlink($strLatestLink);
 
@@ -817,6 +823,7 @@ sub expire
         'expire' .
         (defined($$oParam{iRetentionFull}) ? " full=$$oParam{iRetentionFull}" : '') .
         (defined($$oParam{iRetentionDiff}) ? " diff=$$oParam{iRetentionDiff}" : '') .
+        (defined($$oParam{strOptionalParam}) ? " $$oParam{strOptionalParam}" : '') .
         ' (' . $self->nameGet() . ' host)';
     &log(INFO, "        ${strComment}");
 
@@ -828,6 +835,7 @@ sub expire
         ' --config=' . $self->backrestConfig() .
         (defined($$oParam{iRetentionFull}) ? " --repo1-retention-full=$$oParam{iRetentionFull}" : '') .
         (defined($$oParam{iRetentionDiff}) ? " --repo1-retention-diff=$$oParam{iRetentionDiff}" : '') .
+        (defined($$oParam{strOptionalParam}) ? " $$oParam{strOptionalParam}" : '') .
         '  --stanza=' . $self->stanza() . ' expire',
         {strComment => $strComment, iExpectedExitStatus => $$oParam{iExpectedExitStatus}, oLogTest => $self->{oLogTest},
          bLogOutput => $self->synthetic()});
@@ -1175,9 +1183,9 @@ sub configCreate
         $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-path'} = $self->repoPath();
 
         # S3 settings
-        if ($oParam->{bS3})
+        if ($oParam->{strStorage} eq S3)
         {
-            $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-type'} = STORAGE_S3;
+            $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-type'} = S3;
             $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-s3-key'} = HOST_S3_ACCESS_KEY;
             $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-s3-key-secret'} = HOST_S3_ACCESS_SECRET_KEY;
             $oParamHash{&CFGDEF_SECTION_GLOBAL}{'repo1-s3-bucket'} = HOST_S3_BUCKET;
