@@ -18,11 +18,10 @@ testRun(void)
     FUNCTION_HARNESS_VOID();
 
     // Create default storage object for testing
-    Storage *storageTest = storagePosixNew(
-        strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL);
+    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
 
     // *****************************************************************************************************************************
-    if (testBegin("archiveAsyncStatus()"))
+    if (testBegin("archiveAsyncErrorClear() and archiveAsyncStatus()"))
     {
         StringList *argList = strLstNew();
         strLstAdd(argList, strNewFmt("--spool-path=%s", testPath()));
@@ -44,6 +43,20 @@ testRun(void)
 
         TEST_RESULT_BOOL(archiveAsyncStatus(archiveModePush, segment, false), false, "status file not present");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("clear archive file errors");
+
+        const String *errorSegment = strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s.error", strPtr(segment));
+        const String *errorGlobal = strNew(STORAGE_SPOOL_ARCHIVE_OUT "/global.error");
+
+        storagePutP(storageNewWriteP(storageSpoolWrite(), errorSegment), NULL);
+        storagePutP(storageNewWriteP(storageSpoolWrite(), errorGlobal), NULL);
+
+        TEST_RESULT_VOID(archiveAsyncErrorClear(archiveModePush, segment), "clear error");
+
+        TEST_RESULT_BOOL(storageExistsP(storageSpool(), errorSegment), false, "    check segment error");
+        TEST_RESULT_BOOL(storageExistsP(storageSpool(), errorGlobal), false, "    check global error");
+
         // -------------------------------------------------------------------------------------------------------------------------
         storagePutP(
             storageNewWriteP(storageSpoolWrite(), strNewFmt(STORAGE_SPOOL_ARCHIVE_OUT "/%s.ok", strPtr(segment))),
@@ -112,15 +125,15 @@ testRun(void)
         StringList *argList = strLstNew();
         strLstAdd(argList, strNewFmt("--spool-path=%s", testPath()));
         strLstAddZ(argList, "--stanza=db");
-        strLstAddZ(argList, "archive-get-async");
-        harnessCfgLoad(cfgCmdArchiveGetAsync, argList);
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        harnessCfgLoadRole(cfgCmdArchiveGet, cfgCmdRoleAsync, argList);
 
         String *walSegment = strNew("000000010000000100000001");
 
         TEST_RESULT_VOID(
             archiveAsyncStatusErrorWrite(archiveModeGet, walSegment, 25, strNew("error message")), "write error");
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.error"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.error")))),
             "25\nerror message", "check error");
         TEST_RESULT_VOID(
             storageRemoveP(storageTest, strNew("archive/db/in/000000010000000100000001.error"), .errorOnMissing = true),
@@ -128,8 +141,8 @@ testRun(void)
 
         TEST_RESULT_VOID(
             archiveAsyncStatusErrorWrite(archiveModeGet, NULL, 25, strNew("global error message")), "write global error");
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/global.error"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/global.error")))),
             "25\nglobal error message", "check global error");
         TEST_RESULT_VOID(
             storageRemoveP(storageTest, strNew("archive/db/in/global.error"), .errorOnMissing = true),
@@ -137,8 +150,8 @@ testRun(void)
 
         TEST_RESULT_VOID(
             archiveAsyncStatusOkWrite(archiveModeGet, walSegment, NULL), "write ok file");
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.ok"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.ok")))),
             "", "check ok");
         TEST_RESULT_VOID(
             storageRemoveP(storageTest, strNew("archive/db/in/000000010000000100000001.ok"), .errorOnMissing = true),
@@ -146,8 +159,8 @@ testRun(void)
 
         TEST_RESULT_VOID(
             archiveAsyncStatusOkWrite(archiveModeGet, walSegment, strNew("WARNING")), "write ok file with warning");
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.ok"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageTest, strNew("archive/db/in/000000010000000100000001.ok")))),
             "0\nWARNING", "check ok warning");
         TEST_RESULT_VOID(
             storageRemoveP(storageTest, strNew("archive/db/in/000000010000000100000001.ok"), .errorOnMissing = true),
@@ -175,11 +188,10 @@ testRun(void)
         const String *pgPath = storagePathP(storageTest, STRDEF("pg"));
         storagePathCreateP(storageTest, pgPath);
 
-        TEST_RESULT_STR(
-            strPtr(walPath(strNew("/absolute/path"), pgPath, strNew("test"))), "/absolute/path", "absolute path");
+        TEST_RESULT_STR_Z(walPath(strNew("/absolute/path"), pgPath, strNew("test")), "/absolute/path", "absolute path");
 
         THROW_ON_SYS_ERROR(chdir(strPtr(pgPath)) != 0, PathMissingError, "unable to chdir()");
-        TEST_RESULT_STR_STR(
+        TEST_RESULT_STR(
             walPath(strNew("relative/path"), pgPath, strNew("test")), strNewFmt("%s/relative/path", strPtr(pgPath)),
             "relative path");
 
@@ -190,7 +202,7 @@ testRun(void)
             "unable to create symlink '%s' to '%s'", strPtr(pgPath), strPtr(pgPathLink));
 
         THROW_ON_SYS_ERROR(chdir(strPtr(pgPath)) != 0, PathMissingError, "unable to chdir()");
-        TEST_RESULT_STR_STR(
+        TEST_RESULT_STR(
             walPath(strNew("relative/path"), pgPathLink, strNew("test")), strNewFmt("%s/relative/path", strPtr(pgPathLink)),
             "relative path");
 
@@ -221,9 +233,11 @@ testRun(void)
 
         storagePathCreateP(storageTest, strNew("archive/db/9.6-2/1234567812345678"));
         TEST_RESULT_PTR(walSegmentFind(storageRepo(), strNew("9.6-2"), strNew("123456781234567812345678"), 0), NULL, "no segment");
-        TEST_RESULT_PTR(
-            walSegmentFind(storageRepo(), strNew("9.6-2"), strNew("123456781234567812345678"), 500), NULL,
-            "no segment after 500ms");
+        TEST_ERROR(
+            walSegmentFind(storageRepo(), strNew("9.6-2"), strNew("123456781234567812345678"), 100), ArchiveTimeoutError,
+            "WAL segment 123456781234567812345678 was not archived before the 100ms timeout\n"
+            "HINT: check the archive_command to ensure that all options are correct (especially --stanza).\n"
+            "HINT: check the PostgreSQL server log for errors.");
 
         // Check timeout by making the wal segment appear after 250ms
         HARNESS_FORK_BEGIN()
@@ -243,8 +257,8 @@ testRun(void)
 
             HARNESS_FORK_PARENT_BEGIN()
             {
-                TEST_RESULT_STR(
-                    strPtr(walSegmentFind(storageRepo(), strNew("9.6-2"), strNew("123456781234567812345678"), 1000)),
+                TEST_RESULT_STR_Z(
+                    walSegmentFind(storageRepo(), strNew("9.6-2"), strNew("123456781234567812345678"), 1000),
                     "123456781234567812345678-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa", "found segment");
             }
             HARNESS_FORK_PARENT_END();
@@ -273,47 +287,47 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("walSegmentNext()"))
     {
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("000000010000000100000001"), 16 * 1024 * 1024, PG_VERSION_10)),
-            "000000010000000100000002", "get next");
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("0000000100000001000000FE"), 16 * 1024 * 1024, PG_VERSION_93)),
-            "0000000100000001000000FF", "get next");
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("0000009900000001000000FF"), 16 * 1024 * 1024, PG_VERSION_93)),
-            "000000990000000200000000", "get next overflow >= 9.3");
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("0000000100000001000000FE"), 16 * 1024 * 1024, PG_VERSION_92)),
-            "000000010000000200000000", "get next overflow < 9.3");
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("000000010000000100000003"), 1024 * 1024 * 1024, PG_VERSION_11)),
-            "000000010000000200000000", "get next overflow >= 11/1GB");
-        TEST_RESULT_STR(
-            strPtr(walSegmentNext(strNew("000000010000006700000FFF"), 1024 * 1024, PG_VERSION_11)),
-            "000000010000006800000000", "get next overflow >= 11/1MB");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("000000010000000100000001"), 16 * 1024 * 1024, PG_VERSION_10), "000000010000000100000002",
+            "get next");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("0000000100000001000000FE"), 16 * 1024 * 1024, PG_VERSION_93), "0000000100000001000000FF",
+            "get next");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("0000009900000001000000FF"), 16 * 1024 * 1024, PG_VERSION_93), "000000990000000200000000",
+            "get next overflow >= 9.3");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("0000000100000001000000FE"), 16 * 1024 * 1024, PG_VERSION_92), "000000010000000200000000",
+            "get next overflow < 9.3");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("000000010000000100000003"), 1024 * 1024 * 1024, PG_VERSION_11), "000000010000000200000000",
+            "get next overflow >= 11/1GB");
+        TEST_RESULT_STR_Z(
+            walSegmentNext(strNew("000000010000006700000FFF"), 1024 * 1024, PG_VERSION_11), "000000010000006800000000",
+            "get next overflow >= 11/1MB");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("walSegmentRange()"))
     {
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(walSegmentRange(strNew("000000010000000100000000"), 16 * 1024 * 1024, PG_VERSION_92, 1), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(walSegmentRange(strNew("000000010000000100000000"), 16 * 1024 * 1024, PG_VERSION_92, 1), "|"),
             "000000010000000100000000", "get single");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_92, 4), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_92, 4), "|"),
             "0000000100000001000000FD|0000000100000001000000FE|000000010000000200000000|000000010000000200000001",
             "get range < 9.3");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_93, 4), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(walSegmentRange(strNew("0000000100000001000000FD"), 16 * 1024 * 1024, PG_VERSION_93, 4), "|"),
             "0000000100000001000000FD|0000000100000001000000FE|0000000100000001000000FF|000000010000000200000000",
             "get range >= 9.3");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(walSegmentRange(strNew("000000080000000A00000000"), 1024 * 1024 * 1024, PG_VERSION_11, 8), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(walSegmentRange(strNew("000000080000000A00000000"), 1024 * 1024 * 1024, PG_VERSION_11, 8), "|"),
             "000000080000000A00000000|000000080000000A00000001|000000080000000A00000002|000000080000000A00000003|"
             "000000080000000B00000000|000000080000000B00000001|000000080000000B00000002|000000080000000B00000003",
             "get range >= 11/1GB");
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(walSegmentRange(strNew("000000070000000700000FFE"), 1024 * 1024, PG_VERSION_11, 4), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(walSegmentRange(strNew("000000070000000700000FFE"), 1024 * 1024, PG_VERSION_11, 4), "|"),
             "000000070000000700000FFE|000000070000000700000FFF|000000070000000800000000|000000070000000800000001",
             "get range >= 11/1MB");
     }
