@@ -22,8 +22,7 @@ testRun(void)
     FUNCTION_HARNESS_VOID();
 
     // Create default storage object for testing
-    Storage *storageTest = storagePosixNew(
-        strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL);
+    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
 
     // Start a protocol server to test the protocol directly
     Buffer *serverWrite = bufNew(8192);
@@ -42,7 +41,8 @@ testRun(void)
         strLstAddZ(argList, "--stanza=db");
         strLstAdd(argList, strNewFmt("--pg1-path=%s/db", testPath()));
         strLstAdd(argList, strNewFmt("--spool-path=%s/spool", testPath()));
-        harnessCfgLoad(cfgCmdArchivePushAsync, argList);
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argList);
 
         storagePathCreateP(storagePgWrite(), strNew("pg_wal/archive_status"));
         storagePathCreateP(storageTest, strNew("spool/archive/db/out"));
@@ -67,19 +67,19 @@ testRun(void)
         storagePutP(storageNewWriteP(storagePgWrite(), strNew("pg_wal/archive_status/000000010000000100000005.ready")), NULL);
         storagePutP(storageNewWriteP(storagePgWrite(), strNew("pg_wal/archive_status/000000010000000100000006.ready")), NULL);
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(archivePushProcessList(strNewFmt("%s/db/pg_wal", testPath())), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(archivePushProcessList(strNewFmt("%s/db/pg_wal", testPath())), "|"),
             "000000010000000100000002|000000010000000100000005|000000010000000100000006", "ready list");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|"),
             "000000010000000100000003.ok", "remaining status list");
 
         // Test drop
         // -------------------------------------------------------------------------------------------------------------------------
         StringList *argListDrop = strLstDup(argList);
         strLstAdd(argListDrop, strNewFmt("--archive-push-queue-max=%zu", (size_t)1024 * 1024 * 1024));
-        harnessCfgLoad(cfgCmdArchivePushAsync, argListDrop);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argListDrop);
 
         // Write the files that we claim are in pg_wal
         Buffer *walBuffer = bufNew((size_t)16 * 1024 * 1024);
@@ -100,7 +100,7 @@ testRun(void)
         // Now set queue max low enough that WAL will be dropped
         argListDrop = strLstDup(argList);
         strLstAdd(argListDrop, strNewFmt("--archive-push-queue-max=%zu", (size_t)16 * 1024 * 1024 * 2));
-        harnessCfgLoad(cfgCmdArchivePushAsync, argListDrop);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argListDrop);
 
         TEST_RESULT_BOOL(
             archivePushDrop(strNew("pg_wal"), archivePushProcessList(strNewFmt("%s/db/pg_wal", testPath()))), true,
@@ -133,7 +133,7 @@ testRun(void)
                 "1={\"db-id\":5555555555555555555,\"db-version\":\"9.4\"}\n"));
 
         TEST_ERROR(
-            archivePushCheck(cipherTypeNone, NULL), ArchiveMismatchError,
+            archivePushCheck(true, cipherTypeNone, NULL), ArchiveMismatchError,
             "PostgreSQL version 9.6, system-id 18072658121562454734 do not match stanza version 9.4, system-id 5555555555555555555"
                 "\nHINT: are you archiving to the correct stanza?");
 
@@ -148,7 +148,7 @@ testRun(void)
                 "1={\"db-id\":5555555555555555555,\"db-version\":\"9.6\"}\n"));
 
         TEST_ERROR(
-            archivePushCheck(cipherTypeNone, NULL), ArchiveMismatchError,
+            archivePushCheck(true, cipherTypeNone, NULL), ArchiveMismatchError,
             "PostgreSQL version 9.6, system-id 18072658121562454734 do not match stanza version 9.6, system-id 5555555555555555555"
                 "\nHINT: are you archiving to the correct stanza?");
 
@@ -163,19 +163,29 @@ testRun(void)
                 "1={\"db-id\":18072658121562454734,\"db-version\":\"9.6\"}\n"));
 
         ArchivePushCheckResult result = {0};
-        TEST_ASSIGN(result, archivePushCheck(cipherTypeNone, NULL), "get archive check result");
+        TEST_ASSIGN(result, archivePushCheck(true, cipherTypeNone, NULL), "get archive check result");
 
         TEST_RESULT_UINT(result.pgVersion, PG_VERSION_96, "check pg version");
         TEST_RESULT_UINT(result.pgSystemId, 0xFACEFACEFACEFACE, "check pg system id");
-        TEST_RESULT_UINT(result.pgWalSegmentSize, 16 * 1024 * 1024, "check wal segment size");
-        TEST_RESULT_STR(strPtr(result.archiveId), "9.6-1", "check archive id");
-        TEST_RESULT_STR(strPtr(result.archiveCipherPass), NULL, "check archive cipher pass (not set in this test)");
+        TEST_RESULT_STR_Z(result.archiveId, "9.6-1", "check archive id");
+        TEST_RESULT_STR_Z(result.archiveCipherPass, NULL, "check archive cipher pass (not set in this test)");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("Synchronous cmdArchivePush(), archivePushFile() and archivePushProtocol()"))
     {
+        TEST_TITLE("command must be run on the pg host");
+
         StringList *argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_PG1_HOST "=host");
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/pg");
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test2");
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleDefault, argList);
+
+        TEST_ERROR(cmdArchivePush(), HostInvalidError, "archive-push command must be run on the PostgreSQL host");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        argList = strLstNew();
         strLstAddZ(argList, "--stanza=test");
         harnessCfgLoad(cfgCmdArchivePush, argList);
 
@@ -280,12 +290,16 @@ testRun(void)
 
         TEST_ERROR(cmdArchivePush(), ArchiveDuplicateError, "WAL file '000000010000000100000001' already exists in the archive");
 
-        // Save it to a new file instead
-        argListTemp = strLstDup(argList);
-        strLstAddZ(argListTemp, "pg_wal/000000010000000100000002");
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("WAL with absolute path and no pg1-path");
+
+        argListTemp = strLstNew();
+        strLstAddZ(argListTemp, "--" CFGOPT_STANZA "=test");
+        strLstAdd(argListTemp, strNewFmt("--" CFGOPT_REPO1_PATH "=%s/repo", testPath()));
+        strLstAdd(argListTemp, strNewFmt("%s/pg/pg_wal/000000010000000100000002", testPath()));
         harnessCfgLoad(cfgCmdArchivePush, argListTemp);
 
-        storagePutP(storageNewWriteP(storagePgWrite(), strNew("pg_wal/000000010000000100000002")), walBuffer2);
+        TEST_RESULT_VOID(storagePutP(storageNewWriteP(storageTest, strNew("pg/pg_wal/000000010000000100000002")), walBuffer2), "write WAL");
 
         TEST_RESULT_VOID(cmdArchivePush(), "push the WAL segment");
         harnessLogResult("P00   INFO: pushed WAL file '000000010000000100000002' to the archive");
@@ -351,8 +365,8 @@ testRun(void)
 
         TEST_RESULT_BOOL(
             archivePushProtocol(PROTOCOL_COMMAND_ARCHIVE_PUSH_STR, paramList, server), true, "protocol archive put");
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(serverWrite)),
+        TEST_RESULT_STR_Z(
+            strNewBuf(serverWrite),
             "{\"out\":\"WAL file '000000010000000100000002' already exists in the archive with the same checksum"
                 "\\nHINT: this is valid in some recovery scenarios but may also indicate a problem.\"}\n",
             "check result");
@@ -411,9 +425,33 @@ testRun(void)
     {
         harnessLogLevelSet(logLevelDetail);
 
+        TEST_TITLE("command must be run on the pg host");
+
+        StringList *argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_PG1_HOST "=host");
+        strLstAddZ(argList, "--" CFGOPT_PG1_PATH "=/pg");
+        strLstAddZ(argList, "--" CFGOPT_SPOOL_PATH "=/spool");
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test2");
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argList);
+
+        TEST_ERROR(cmdArchivePush(), HostInvalidError, "archive-push command must be run on the PostgreSQL host");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("pg1-path must be set when async");
+
+        argList = strLstNew();
+        strLstAddZ(argList, "--" CFGOPT_SPOOL_PATH "=/spool");
+        strLstAddZ(argList, "--" CFGOPT_STANZA "=test2");
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
+        strLstAddZ(argList, "/000000010000000100000001");
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argList);
+
+        TEST_ERROR(cmdArchivePush(), OptionRequiredError, "'archive-push' command in async mode requires option 'pg1-path'");
+
         // Call with a bogus exe name so the async process will error out and we can make sure timeouts work
         // -------------------------------------------------------------------------------------------------------------------------
-        StringList *argList = strLstNew();
+        argList = strLstNew();
         strLstAddZ(argList, "pgbackrest-bogus");
         strLstAddZ(argList, "--stanza=test");
         strLstAddZ(argList, "--archive-async");
@@ -556,10 +594,11 @@ testRun(void)
         strLstAddZ(argList, "--stanza=test");
         strLstAddZ(argList, "--no-compress");
         strLstAdd(argList, strNewFmt("--spool-path=%s/spool", testPath()));
+        strLstAddZ(argList, "--" CFGOPT_ARCHIVE_ASYNC);
         strLstAdd(argList, strNewFmt("--pg1-path=%s/pg", testPath()));
         strLstAdd(argList, strNewFmt("--repo1-path=%s/repo", testPath()));
         strLstAddZ(argList, "--log-subprocess");
-        harnessCfgLoad(cfgCmdArchivePushAsync, argList);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argList);
 
         TEST_ERROR(cmdArchivePushAsync(), ParamRequiredError, "WAL path to push required");
 
@@ -576,16 +615,16 @@ testRun(void)
         storagePathCreateP(storagePgWrite(), strNew("pg_xlog/archive_status"));
 
         strLstAdd(argList, strNewFmt("%s/pg/pg_xlog", testPath()));
-        harnessCfgLoad(cfgCmdArchivePushAsync, argList);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argList);
 
         TEST_ERROR(cmdArchivePushAsync(), AssertError, "no WAL files to process");
 
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/global.error"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/global.error")))),
             "25\nno WAL files to process", "check global.error");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|"),
             "global.error", "check status files");
 
         // Push WAL
@@ -614,8 +653,8 @@ testRun(void)
                     TEST_64BIT() ? "f81d63dd5e258cd607534f3531bbd71442797e37" : "02d228126281e8e102b35a2737e45a0527946296")),
             true, "check repo for WAL 1 file");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|"),
             "000000010000000100000001.ok|000000010000000100000002.error", "check status files");
 
         // Create WAL 2 segment
@@ -628,7 +667,7 @@ testRun(void)
 
         argListTemp = strLstDup(argList);
         strLstAddZ(argListTemp, "--archive-push-queue-max=1gb");
-        harnessCfgLoad(cfgCmdArchivePushAsync, argListTemp);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argListTemp);
 
         TEST_RESULT_VOID(cmdArchivePushAsync(), "push WAL segments");
         harnessLogResult(
@@ -643,8 +682,8 @@ testRun(void)
                     TEST_64BIT() ? "0aea6fa5d53500ce548b84a86bc3a29ae77fa048" : "408822a89ef44ef6740e785743bf1b870d8024a2")),
             true, "check repo for WAL 2 file");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|"),
             "000000010000000100000001.ok|000000010000000100000002.ok", "check status files");
 
         // Check that drop functionality works
@@ -655,7 +694,7 @@ testRun(void)
 
         argListTemp = strLstDup(argList);
         strLstAddZ(argListTemp, "--archive-push-queue-max=16m");
-        harnessCfgLoad(cfgCmdArchivePushAsync, argListTemp);
+        harnessCfgLoadRole(cfgCmdArchivePush, cfgCmdRoleAsync, argListTemp);
 
         TEST_RESULT_VOID(cmdArchivePushAsync(), "push WAL segments");
         harnessLogResult(
@@ -663,22 +702,18 @@ testRun(void)
             "P00   WARN: dropped WAL file '000000010000000100000001' because archive queue exceeded 16MB\n"
             "P00   WARN: dropped WAL file '000000010000000100000002' because archive queue exceeded 16MB");
 
-        TEST_RESULT_STR(
-            strPtr(
-                strNewBuf(
-                    storageGetP(
-                        storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(
+                storageGetP(storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000001.ok")))),
             "0\ndropped WAL file '000000010000000100000001' because archive queue exceeded 16MB", "check WAL 1 warning");
 
-        TEST_RESULT_STR(
-            strPtr(
-                strNewBuf(
-                    storageGetP(
-                        storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000002.ok"))))),
+        TEST_RESULT_STR_Z(
+            strNewBuf(
+                storageGetP(storageNewReadP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT "/000000010000000100000002.ok")))),
             "0\ndropped WAL file '000000010000000100000002' because archive queue exceeded 16MB", "check WAL 2 warning");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|")),
+        TEST_RESULT_STR_Z(
+            strLstJoin(strLstSort(storageListP(storageSpool(), strNew(STORAGE_SPOOL_ARCHIVE_OUT)), sortOrderAsc), "|"),
             "000000010000000100000001.ok|000000010000000100000002.ok", "check status files");
         }
 
