@@ -147,7 +147,7 @@ testRun(void)
             "General Options:\n"
             "\n"
             "  --buffer-size                    buffer size for file operations\n"
-            "                                   [current=32768, default=4194304]\n"
+            "                                   [current=32768, default=1048576]\n"
             "  --cmd-ssh                        path to ssh client executable [default=ssh]\n"
             "  --compress-level-network         network compression level [default=3]\n"
             "  --config                         pgBackRest configuration file\n"
@@ -281,12 +281,12 @@ testRun(void)
         strLstAddZ(argList, "buffer-size");
         TEST_RESULT_VOID(
             configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, buffer-size option");
-        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ndefault: 4194304\n", optionHelp), "    check text");
+        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ndefault: 1048576\n", optionHelp), "    check text");
 
         strLstAddZ(argList, "--buffer-size=32768");
         TEST_RESULT_VOID(
             configParse(strLstSize(argList), strLstPtr(argList), false), "help for archive-push command, buffer-size option");
-        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ncurrent: 32768\ndefault: 4194304\n", optionHelp), "    check text");
+        TEST_RESULT_STR(helpRender(), strNewFmt("%s\ncurrent: 32768\ndefault: 1048576\n", optionHelp), "    check text");
 
         // -------------------------------------------------------------------------------------------------------------------------
         optionHelp = strPtr(strNewFmt(
@@ -370,10 +370,13 @@ testRun(void)
             "NOTE: WAL segments required to make a backup consistent are always retained\n"
             "until the backup is expired regardless of how this option is configured.\n"
             "\n"
-            "If this value is not set, then the archive to expire will default to the\n"
-            "repo-retention-full (or repo-retention-diff) value corresponding to the\n"
-            "repo-retention-archive-type if set to full (or diff). This will ensure that WAL\n"
-            "is only expired for backups that are already expired.\n"
+            "If this value is not set and repo-retention-full-type is count (default), then\n"
+            "the archive to expire will default to the repo-retention-full (or\n"
+            "repo-retention-diff) value corresponding to the repo-retention-archive-type if\n"
+            "set to full (or diff). This will ensure that WAL is only expired for backups\n"
+            "that are already expired. If repo-retention-full-type is time, then this value\n"
+            "will default to removing archives that are earlier than the oldest full backup\n"
+            "retained after satisfying the repo-retention-full setting.\n"
             "\n"
             "This option must be set if repo-retention-archive-type is set to incr. If disk\n"
             "space is at a premium, then this setting, in conjunction with\n"
@@ -413,8 +416,7 @@ testRun(void)
         // Restore normal stdout
         dup2(stdoutSave, STDOUT_FILENO);
 
-        Storage *storage = storagePosixNew(
-            strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false, NULL);
+        Storage *storage = storagePosixNewP(strNew(testPath()));
         TEST_RESULT_STR_Z(strNewBuf(storageGetP(storageNewReadP(storage, stdoutFile))), generalHelp, "    check text");
     }
 
