@@ -5,6 +5,7 @@ Test Info Command
 
 #include "common/harnessConfig.h"
 #include "common/harnessInfo.h"
+#include "common/harnessFork.h"
 
 /***********************************************************************************************************************************
 Test Run
@@ -36,10 +37,10 @@ testRun(void)
 
         // No stanzas have been created
         //--------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(strPtr(infoRender()), "[]", "json - repo but no stanzas");
+        TEST_RESULT_STR_Z(infoRender(), "[]", "json - repo but no stanzas");
 
         harnessCfgLoad(cfgCmdInfo, argListText);
-        TEST_RESULT_STR(strPtr(infoRender()), "No stanzas exist in the repository.\n", "text - no stanzas");
+        TEST_RESULT_STR_Z(infoRender(), "No stanzas exist in the repository.\n", "text - no stanzas");
 
         storagePathCreateP(storageLocalWrite(), archivePath);
         storagePathCreateP(storageLocalWrite(), backupPath);
@@ -48,13 +49,16 @@ testRun(void)
         //--------------------------------------------------------------------------------------------------------------------------
         TEST_RESULT_VOID(storagePathCreateP(storageLocalWrite(), backupStanza1Path), "backup stanza1 directory");
         TEST_RESULT_VOID(storagePathCreateP(storageLocalWrite(), archiveStanza1Path), "archive stanza1 directory");
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: error (missing stanza data)\n"
-            "    cipher: none\n", "text - missing stanza data");
+            "    cipher: none\n",
+            "text - missing stanza data");
 
         harnessCfgLoad(cfgCmdInfo, argList);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                     "\"archive\":[],"
@@ -64,10 +68,12 @@ testRun(void)
                     "\"name\":\"stanza1\","
                     "\"status\":{"
                         "\"code\":3,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"missing stanza data\""
                         "}"
                 "}"
-            "]", "json - missing stanza data");
+            "]",
+            "json - missing stanza data");
 
         // backup.info file exists, but archive.info does not
         //--------------------------------------------------------------------------------------------------------------------------
@@ -128,7 +134,8 @@ testRun(void)
 
         // archive section will cross reference backup db-id 2 to archive db-id 3 but db section will only use the db-ids from
         // backup.info
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                     "\"archive\":["
@@ -158,13 +165,16 @@ testRun(void)
                      "\"name\":\"stanza1\","
                      "\"status\":{"
                         "\"code\":2,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"no valid backups\""
                     "}"
                 "}"
-            "]", "json - single stanza, no valid backups");
+            "]",
+            "json - single stanza, no valid backups");
 
         harnessCfgLoad(cfgCmdInfo, argListText);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: error (no valid backups)\n"
             "    cipher: aes-256-cbc\n"
@@ -173,6 +183,79 @@ testRun(void)
             "        wal archive min/max (9.4-3): none present\n",
             "text - single stanza, no valid backups");
 
+        // Repeat prior tests while a backup lock is held
+        HARNESS_FORK_BEGIN()
+        {
+            HARNESS_FORK_CHILD_BEGIN(0, false)
+            {
+                TEST_RESULT_INT_NE(
+                    lockAcquire(cfgOptionStr(cfgOptLockPath), strNew("stanza1"), lockTypeBackup, 0, true), -1,
+                    "create backup/expire lock");
+
+                sleepMSec(1000);
+                lockRelease(true);
+            }
+            HARNESS_FORK_CHILD_END();
+
+            HARNESS_FORK_PARENT_BEGIN()
+            {
+                sleepMSec(250);
+
+                harnessCfgLoad(cfgCmdInfo, argList);
+                TEST_RESULT_STR_Z(
+                    infoRender(),
+                    "["
+                        "{"
+                            "\"archive\":["
+                                "{"
+                                    "\"database\":{"
+                                        "\"id\":2"
+                                    "},"
+                                    "\"id\":\"9.4-3\","
+                                    "\"max\":null,"
+                                    "\"min\":null"
+                                "}"
+                            "],"
+                             "\"backup\":[],"
+                             "\"cipher\":\"aes-256-cbc\","
+                             "\"db\":["
+                                "{"
+                                    "\"id\":1,"
+                                    "\"system-id\":6569239123849665666,"
+                                    "\"version\":\"9.3\""
+                                "},"
+                                "{"
+                                    "\"id\":2,"
+                                    "\"system-id\":6569239123849665679,"
+                                    "\"version\":\"9.4\""
+                                "}"
+                            "],"
+                             "\"name\":\"stanza1\","
+                             "\"status\":{"
+                                "\"code\":2,"
+                                "\"lock\":{\"backup\":{\"held\":true}},"
+                                "\"message\":\"no valid backups\""
+                            "}"
+                        "}"
+                    "]",
+                    "json - single stanza, no valid backups, backup/expire lock detected");
+
+                harnessCfgLoad(cfgCmdInfo, argListText);
+                TEST_RESULT_STR_Z(
+                    infoRender(),
+                    "stanza: stanza1\n"
+                    "    status: error (no valid backups, backup/expire running)\n"
+                    "    cipher: aes-256-cbc\n"
+                    "\n"
+                    "    db (current)\n"
+                    "        wal archive min/max (9.4-3): none present\n",
+                    "text - single stanza, no valid backups, backup/expire lock detected");
+
+            }
+            HARNESS_FORK_PARENT_END();
+        }
+        HARNESS_FORK_END();
+
         // Add WAL segments
         //--------------------------------------------------------------------------------------------------------------------------
         String *archiveDb3 = strNewFmt("%s/9.4-3/0000000100000000", strPtr(archiveStanza1Path));
@@ -186,7 +269,8 @@ testRun(void)
         strLstAddZ(argList2, "--stanza=stanza1");
         harnessCfgLoad(cfgCmdInfo, argList2);
 
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: error (no valid backups)\n"
             "    cipher: aes-256-cbc\n"
@@ -249,7 +333,8 @@ testRun(void)
             storagePutP(storageNewWriteP(storageLocalWrite(), strNewFmt("%s/backup.info", strPtr(backupStanza1Path))),
                 harnessInfoChecksum(content)), "put backup info to file");
 
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                      "\"archive\":["
@@ -322,13 +407,16 @@ testRun(void)
                      "\"name\":\"stanza1\","
                      "\"status\":{"
                         "\"code\":0,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"ok\""
                     "}"
                 "}"
-            "]", "json - single stanza, valid backup, no priors, no archives in latest DB");
+            "]",
+            "json - single stanza, valid backup, no priors, no archives in latest DB");
 
         harnessCfgLoad(cfgCmdInfo, argListText);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: ok\n"
             "    cipher: none\n"
@@ -343,8 +431,132 @@ testRun(void)
             "            repository size: 3MB, repository backup size: 3KB\n"
             "\n"
             "    db (current)\n"
-            "        wal archive min/max (9.4-3): none present\n"
-            ,"text - single stanza, valid backup, no priors, no archives in latest DB");
+            "        wal archive min/max (9.4-3): none present\n",
+            "text - single stanza, valid backup, no priors, no archives in latest DB");
+
+        // Repeat prior tests while a backup lock is held
+        HARNESS_FORK_BEGIN()
+        {
+            HARNESS_FORK_CHILD_BEGIN(0, false)
+            {
+                TEST_RESULT_INT_NE(
+                    lockAcquire(cfgOptionStr(cfgOptLockPath), strNew("stanza1"), lockTypeBackup, 0, true), -1,
+                    "create backup/expire lock");
+
+                sleepMSec(1000);
+                lockRelease(true);
+            }
+            HARNESS_FORK_CHILD_END();
+
+            HARNESS_FORK_PARENT_BEGIN()
+            {
+                sleepMSec(250);
+
+                harnessCfgLoad(cfgCmdInfo, argList);
+                TEST_RESULT_STR_Z(
+                    infoRender(),
+                    "["
+                        "{"
+                             "\"archive\":["
+                                "{"
+                                    "\"database\":{"
+                                        "\"id\":1"
+                                    "},"
+                                    "\"id\":\"9.4-1\","
+                                    "\"max\":\"000000020000000000000003\","
+                                    "\"min\":\"000000010000000000000002\""
+                                "},"
+                                "{"
+                                    "\"database\":{"
+                                        "\"id\":3"
+                                    "},"
+                                    "\"id\":\"9.4-3\","
+                                    "\"max\":null,"
+                                    "\"min\":null"
+                                "}"
+                            "],"
+                             "\"backup\":["
+                                "{"
+                                    "\"archive\":{"
+                                        "\"start\":null,"
+                                        "\"stop\":null"
+                                    "},"
+                                    "\"backrest\":{"
+                                        "\"format\":5,"
+                                        "\"version\":\"2.04\""
+                                    "},"
+                                    "\"database\":{"
+                                        "\"id\":1"
+                                    "},"
+                                    "\"info\":{"
+                                        "\"delta\":26897030,"
+                                        "\"repository\":{"
+                                            "\"delta\":3159,"
+                                            "\"size\":3159776"
+                                        "},"
+                                        "\"size\":26897030"
+                                    "},"
+                                    "\"label\":\"20181116-154756F\","
+                                    "\"prior\":null,"
+                                    "\"reference\":null,"
+                                    "\"timestamp\":{"
+                                        "\"start\":1542383276,"
+                                        "\"stop\":1542383289"
+                                    "},"
+                                    "\"type\":\"full\""
+                                "}"
+                            "],"
+                             "\"cipher\":\"none\","
+                             "\"db\":["
+                                "{"
+                                    "\"id\":1,"
+                                    "\"system-id\":6569239123849665679,"
+                                    "\"version\":\"9.4\""
+                                "},"
+                                "{"
+                                    "\"id\":2,"
+                                    "\"system-id\":6569239123849665666,"
+                                    "\"version\":\"9.3\""
+                                "},"
+                                "{"
+                                    "\"id\":3,"
+                                    "\"system-id\":6569239123849665679,"
+                                    "\"version\":\"9.4\""
+                                "}"
+                            "],"
+                             "\"name\":\"stanza1\","
+                             "\"status\":{"
+                                "\"code\":0,"
+                                "\"lock\":{\"backup\":{\"held\":true}},"
+                                "\"message\":\"ok\""
+                            "}"
+                        "}"
+                    "]",
+                    "json - single stanza, valid backup, no priors, no archives in latest DB, backup/expire lock detected");
+
+                harnessCfgLoad(cfgCmdInfo, argListText);
+                TEST_RESULT_STR_Z(
+                    infoRender(),
+                    "stanza: stanza1\n"
+                    "    status: ok (backup/expire running)\n"
+                    "    cipher: none\n"
+                    "\n"
+                    "    db (prior)\n"
+                    "        wal archive min/max (9.4-1): 000000010000000000000002/000000020000000000000003\n"
+                    "\n"
+                    "        full backup: 20181116-154756F\n"
+                    "            timestamp start/stop: 2018-11-16 15:47:56 / 2018-11-16 15:48:09\n"
+                    "            wal start/stop: n/a\n"
+                    "            database size: 25.7MB, backup size: 25.7MB\n"
+                    "            repository size: 3MB, repository backup size: 3KB\n"
+                    "\n"
+                    "    db (current)\n"
+                    "        wal archive min/max (9.4-3): none present\n",
+                    "text - single stanza, valid backup, no priors, no archives in latest DB, backup/expire lock detected");
+            }
+            HARNESS_FORK_PARENT_END();
+        }
+        HARNESS_FORK_END();
 
         // backup.info/archive.info files exist, backups exist, archives exist
         //--------------------------------------------------------------------------------------------------------------------------
@@ -574,7 +786,8 @@ testRun(void)
                 harnessInfoChecksum(content)), "put backup info to file - stanza2");
 
         harnessCfgLoad(cfgCmdInfo, argList);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                      "\"archive\":["
@@ -705,6 +918,7 @@ testRun(void)
                      "\"name\":\"stanza1\","
                      "\"status\":{"
                         "\"code\":0,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"ok\""
                     "}"
                 "},"
@@ -731,13 +945,16 @@ testRun(void)
                      "\"name\":\"stanza2\","
                      "\"status\":{"
                         "\"code\":2,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"no valid backups\""
                     "}"
                 "}"
-            "]", "json - multiple stanzas, one with valid backups, archives in latest DB");
+            "]",
+            "json - multiple stanzas, one with valid backups, archives in latest DB");
 
         harnessCfgLoad(cfgCmdInfo, argListText);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: ok\n"
             "    cipher: none\n"
@@ -773,8 +990,8 @@ testRun(void)
             "    cipher: none\n"
             "\n"
             "    db (current)\n"
-            "        wal archive min/max (9.4-1): none present\n"
-            , "text - multiple stanzas, one with valid backups, archives in latest DB");
+            "        wal archive min/max (9.4-1): none present\n",
+            "text - multiple stanzas, one with valid backups, archives in latest DB");
 
         // Backup set requested
         //--------------------------------------------------------------------------------------------------------------------------
@@ -783,8 +1000,8 @@ testRun(void)
         strLstAddZ(argList2, "--set=20181119-152138F_20181119-152152I");
         harnessCfgLoad(cfgCmdInfo, argList2);
 
-        TEST_RESULT_STR(strPtr(infoRender()),
-
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: ok\n"
             "    cipher: none\n"
@@ -804,8 +1021,8 @@ testRun(void)
             "                pg_stat => ../pg_stat\n"
             "            tablespaces:\n"
             "                ts1 (1) => /tblspc/ts1\n"
-            "                ts12 (12) => /tblspc/ts12\n"
-            , "text - backup set requested");
+            "                ts12 (12) => /tblspc/ts12\n",
+            "text - backup set requested");
 
         strLstAddZ(argList2, "--output=json");
         harnessCfgLoad(cfgCmdInfo, argList2);
@@ -844,7 +1061,8 @@ testRun(void)
                     contentLoad),
                 "write manifest");
 
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: ok\n"
             "    cipher: none\n"
@@ -858,9 +1076,8 @@ testRun(void)
             "            database size: 19.2MB, backup size: 8.2KB\n"
             "            repository size: 2.3MB, repository backup size: 346B\n"
             "            backup reference list: 20181119-152138F, 20181119-152138F_20181119-152152D\n"
-            "            database list: mail (16456), postgres (12173)\n"
-            , "text - backup set requested, no links");
-
+            "            database list: mail (16456), postgres (12173)\n",
+            "text - backup set requested, no links");
 
         // Backup set requested but no databases
         //--------------------------------------------------------------------------------------------------------------------------
@@ -895,7 +1112,8 @@ testRun(void)
                     contentLoad),
             "write manifest");
 
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza1\n"
             "    status: ok\n"
             "    cipher: none\n"
@@ -909,15 +1127,16 @@ testRun(void)
             "            database size: 19.2MB, backup size: 8.2KB\n"
             "            repository size: 2.3MB, repository backup size: 346B\n"
             "            backup reference list: 20181119-152138F, 20181119-152138F_20181119-152152D\n"
-            "            database list: none\n"
-            , "text - backup set requested, no db");
+            "            database list: none\n",
+            "text - backup set requested, no db");
 
         // Stanza not found
         //--------------------------------------------------------------------------------------------------------------------------
         argList2 = strLstDup(argList);
         strLstAddZ(argList2, "--stanza=silly");
         harnessCfgLoad(cfgCmdInfo, argList2);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                      "\"backup\":[],"
@@ -925,24 +1144,28 @@ testRun(void)
                      "\"name\":\"silly\","
                      "\"status\":{"
                         "\"code\":1,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"missing stanza path\""
                     "}"
                 "}"
-            "]", "json - missing stanza path");
+            "]",
+            "json - missing stanza path");
 
         StringList *argListText2 = strLstDup(argListText);
         strLstAddZ(argListText2, "--stanza=silly");
         harnessCfgLoad(cfgCmdInfo, argListText2);
-        TEST_RESULT_STR(strPtr(infoRender()),
-        "stanza: silly\n"
-        "    status: error (missing stanza path)\n"
-        , "text - missing stanza path");
+        TEST_RESULT_STR_Z(
+            infoRender(),
+            "stanza: silly\n"
+            "    status: error (missing stanza path)\n",
+            "text - missing stanza path");
 
         // Stanza found
         //--------------------------------------------------------------------------------------------------------------------------
         strLstAddZ(argList, "--stanza=stanza2");
         harnessCfgLoad(cfgCmdInfo, argList);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "["
                 "{"
                      "\"archive\":["
@@ -967,21 +1190,24 @@ testRun(void)
                      "\"name\":\"stanza2\","
                      "\"status\":{"
                         "\"code\":2,"
+                        "\"lock\":{\"backup\":{\"held\":false}},"
                         "\"message\":\"no valid backups\""
                     "}"
                 "}"
-            "]", "json - multiple stanzas - selected found");
+            "]",
+            "json - multiple stanzas - selected found");
 
         strLstAddZ(argListText, "--stanza=stanza2");
         harnessCfgLoad(cfgCmdInfo, argListText);
-        TEST_RESULT_STR(strPtr(infoRender()),
+        TEST_RESULT_STR_Z(
+            infoRender(),
             "stanza: stanza2\n"
             "    status: error (no valid backups)\n"
             "    cipher: none\n"
             "\n"
             "    db (current)\n"
-            "        wal archive min/max (9.4-1): none present\n"
-            ,"text - multiple stanzas - selected found");
+            "        wal archive min/max (9.4-1): none present\n",
+            "text - multiple stanzas - selected found");
 
         // Crypto error
         //--------------------------------------------------------------------------------------------------------------------------
@@ -1052,15 +1278,16 @@ testRun(void)
         String *result = strNew("");
         formatTextDb(stanzaInfo, result, NULL);
 
-        TEST_RESULT_STR(strPtr(result),
+        TEST_RESULT_STR_Z(
+            result,
             "\n"
             "    db (current)\n"
             "        full backup: 20181119-152138F\n"
             "            timestamp start/stop: 2018-11-16 15:47:56 / 2018-11-16 15:48:09\n"
             "            wal start/stop: n/a\n"
             "            database size: 0B, backup size: 0B\n"
-            "            repository size: 0B, repository backup size: 0B\n"
-            ,"formatTextDb only backup section (code coverage only)");
+            "            repository size: 0B, repository backup size: 0B\n",
+            "formatTextDb only backup section (code coverage only)");
     }
 
     //******************************************************************************************************************************
@@ -1085,10 +1312,9 @@ testRun(void)
         // Restore normal stdout
         dup2(stdoutSave, STDOUT_FILENO);
 
-        Storage *storage = storagePosixNew(
-            strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, false, NULL);
-        TEST_RESULT_STR(
-            strPtr(strNewBuf(storageGetP(storageNewReadP(storage, stdoutFile)))), "No stanzas exist in the repository.\n",
+        Storage *storage = storagePosixNewP(strNew(testPath()));
+        TEST_RESULT_STR_Z(
+            strNewBuf(storageGetP(storageNewReadP(storage, stdoutFile))), "No stanzas exist in the repository.\n",
             "    check text");
 
         //--------------------------------------------------------------------------------------------------------------------------
