@@ -43,49 +43,31 @@ testRun(void)
         // valgrind will accept
         if (TEST_64BIT())
         {
-            TEST_ERROR(memAllocInternal((size_t)5629499534213120, false), MemoryError, "unable to allocate 5629499534213120 bytes");
+            TEST_ERROR(memAllocInternal((size_t)5629499534213120), MemoryError, "unable to allocate 5629499534213120 bytes");
             TEST_ERROR(memFreeInternal(NULL), AssertError, "assertion 'buffer != NULL' failed");
 
             // Check that bad realloc is caught
-            void *buffer = memAllocInternal(sizeof(size_t), false);
+            void *buffer = memAllocInternal(sizeof(size_t));
             TEST_ERROR(
-                memReAllocInternal(buffer, sizeof(size_t), (size_t)5629499534213120, false), MemoryError,
+                memReAllocInternal(buffer, (size_t)5629499534213120), MemoryError,
                 "unable to reallocate 5629499534213120 bytes");
             memFreeInternal(buffer);
         }
 
-        // Normal memory allocation
-        void *buffer = memAllocInternal(sizeof(size_t), false);
-        buffer = memReAllocInternal(buffer, sizeof(size_t), sizeof(size_t) * 2, false);
-        memFreeInternal(buffer);
+        // Memory allocation
+        void *buffer = memAllocInternal(sizeof(size_t));
+
+        // Memory reallocation
+        memset(buffer, 0xC7, sizeof(size_t));
+
+        unsigned char *buffer2 = memReAllocInternal(buffer, sizeof(size_t) * 2);
 
-        // Zeroed memory allocation
-        unsigned char *buffer2 = memAllocInternal(sizeof(size_t), true);
         int expectedTotal = 0;
 
-        for (unsigned int charIdx = 0; charIdx < sizeof(size_t); charIdx++)
-            expectedTotal += buffer2[charIdx] == 0;
-
-        TEST_RESULT_INT(expectedTotal, sizeof(size_t), "all bytes are 0");
-
-        // Zeroed memory reallocation
-        memset(buffer2, 0xC7, sizeof(size_t));
-
-        buffer2 = memReAllocInternal(buffer2, sizeof(size_t), sizeof(size_t) * 2, true);
-
-        expectedTotal = 0;
-
         for (unsigned int charIdx = 0; charIdx < sizeof(size_t); charIdx++)
             expectedTotal += buffer2[charIdx] == 0xC7;
 
         TEST_RESULT_INT(expectedTotal, sizeof(size_t), "all old bytes are filled");
-
-        expectedTotal = 0;
-
-        for (unsigned int charIdx = 0; charIdx < sizeof(size_t); charIdx++)
-            expectedTotal += (buffer2 + sizeof(size_t))[charIdx] == 0;
-
-        TEST_RESULT_INT(expectedTotal, sizeof(size_t), "all new bytes are 0");
         memFreeInternal(buffer2);
     }
 
@@ -93,7 +75,7 @@ testRun(void)
     if (testBegin("memContextNew() and memContextFree()"))
     {
         // Make sure top context was created
-        TEST_RESULT_STR(memContextName(memContextTop()), "TOP", "top context should exist");
+        TEST_RESULT_Z(memContextName(memContextTop()), "TOP", "top context should exist");
         TEST_RESULT_INT(memContextTop()->contextChildListSize, 0, "top context should init with zero children");
         TEST_RESULT_PTR(memContextTop()->contextChildList, NULL, "top context child list empty");
 
@@ -104,11 +86,15 @@ testRun(void)
         TEST_ERROR(memContextNew(""), AssertError, "assertion 'name[0] != '\\0'' failed");
 
         MemContext *memContext = memContextNew("test1");
-        TEST_RESULT_STR(memContextName(memContext), "test1", "test1 context name");
+        memContextKeep();
+        TEST_RESULT_Z(memContextName(memContext), "test1", "test1 context name");
         TEST_RESULT_PTR(memContext->contextParent, memContextTop(), "test1 context parent is top");
         TEST_RESULT_INT(memContextTop()->contextChildListSize, MEM_CONTEXT_INITIAL_SIZE, "initial top context child list size");
 
-        TEST_RESULT_PTR(memContextSwitch(memContext), memContextTop(), "switch returns top as old context");
+        memContextSwitch(memContext);
+
+        TEST_ERROR(memContextKeep(), AssertError, "new context expected but current context 'test1' found");
+        TEST_ERROR(memContextDiscard(), AssertError, "new context expected but current context 'test1' found");
         TEST_RESULT_PTR(memContext, memContextCurrent(), "current context is now test1");
 
         // Create enough mem contexts to use up the initially allocated block
@@ -116,13 +102,15 @@ testRun(void)
         {
             memContextSwitch(memContextTop());
             memContextNew("test-filler");
+            memContextKeep();
             TEST_RESULT_BOOL(
                 memContextTop()->contextChildList[contextIdx]->state == memContextStateActive, true, "new context is active");
-            TEST_RESULT_STR(memContextName(memContextTop()->contextChildList[contextIdx]), "test-filler", "new context name");
+            TEST_RESULT_Z(memContextName(memContextTop()->contextChildList[contextIdx]), "test-filler", "new context name");
         }
 
         // This forces the child context array to grow
         memContextNew("test5");
+        memContextKeep();
         TEST_RESULT_INT(memContextTop()->contextChildListSize, MEM_CONTEXT_INITIAL_SIZE * 2, "increased child context list size");
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, MEM_CONTEXT_INITIAL_SIZE + 1, "check context free idx");
 
@@ -135,19 +123,22 @@ testRun(void)
 
         // Create a new context and it should end up in the same spot
         memContextNew("test-reuse");
+        memContextKeep();
         TEST_RESULT_BOOL(
             memContextTop()->contextChildList[1]->state == memContextStateActive,
             true, "new context in same index as freed context is active");
-        TEST_RESULT_STR(memContextName(memContextTop()->contextChildList[1]), "test-reuse", "new context name");
+        TEST_RESULT_Z(memContextName(memContextTop()->contextChildList[1]), "test-reuse", "new context name");
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, 2, "check context free idx");
 
         // Next context will be at the end
         memContextNew("test-at-end");
+        memContextKeep();
         TEST_RESULT_UINT(memContextTop()->contextChildFreeIdx, MEM_CONTEXT_INITIAL_SIZE + 2, "check context free idx");
 
         // Create a child context to test recursive free
         memContextSwitch(memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]);
         memContextNew("test-reuse");
+        memContextKeep();
         TEST_RESULT_PTR_NE(
             memContextTop()->contextChildList[MEM_CONTEXT_INITIAL_SIZE]->contextChildList, NULL, "context child list is allocated");
         TEST_RESULT_INT(
@@ -166,6 +157,7 @@ testRun(void)
             AssertError, "cannot free inactive context");
 
         MemContext *noAllocation = memContextNew("empty");
+        memContextKeep();
         noAllocation->allocListSize = 0;
         free(noAllocation->allocList);
         TEST_RESULT_VOID(memContextFree(noAllocation), "free context with no allocations");
@@ -174,23 +166,21 @@ testRun(void)
     // *****************************************************************************************************************************
     if (testBegin("memContextAlloc(), memNew*(), memGrow(), and memFree()"))
     {
+        TEST_RESULT_UINT(sizeof(MemContextAlloc), 8, "check MemContextAlloc size (same for 32/64 bit)");
+        TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_BUFFER((void *)0), (void *)sizeof(MemContextAlloc), "check buffer macro");
+        TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_HEADER((void *)sizeof(MemContextAlloc)), (void *)0, "check header macro");
+
         memContextSwitch(memContextTop());
-        memNew(sizeof(size_t));
+        memNewPtrArray(1);
 
         MemContext *memContext = memContextNew("test-alloc");
+        TEST_ERROR(memContextSwitchBack(), AssertError, "current context expected but new context 'test-alloc' found");
+        memContextKeep();
         memContextSwitch(memContext);
 
         for (int allocIdx = 0; allocIdx <= MEM_CONTEXT_ALLOC_INITIAL_SIZE; allocIdx++)
         {
-            unsigned char *buffer = memNew(sizeof(size_t));
-
-            // Check that the buffer is zeroed
-            int expectedTotal = 0;
-
-            for (unsigned int charIdx = 0; charIdx < sizeof(size_t); charIdx++)
-                expectedTotal += buffer[charIdx] == 0;
-
-            TEST_RESULT_INT(expectedTotal, sizeof(size_t), "all bytes are 0");
+            memNew(sizeof(size_t));
 
             TEST_RESULT_INT(
                 memContextCurrent()->allocListSize,
@@ -198,12 +188,11 @@ testRun(void)
                 "allocation list size");
         }
 
-
-        unsigned char *buffer = memNewRaw(sizeof(size_t));
+        unsigned char *buffer = memNew(sizeof(size_t));
 
         // Grow memory
         memset(buffer, 0xFE, sizeof(size_t));
-        buffer = memGrowRaw(buffer, sizeof(size_t) * 2);
+        buffer = memResize(buffer, sizeof(size_t) * 2);
 
         // Check that original portion of the buffer is preserved
         int expectedTotal = 0;
@@ -215,11 +204,10 @@ testRun(void)
 
         // Free memory
         TEST_RESULT_UINT(memContextCurrent()->allocFreeIdx, MEM_CONTEXT_ALLOC_INITIAL_SIZE + 2, "check alloc free idx");
-        TEST_RESULT_VOID(memFree(memContextCurrent()->allocList[0].buffer), "free allocation");
-        TEST_ERROR(memFree(memContextCurrent()->allocList[0].buffer), AssertError, "unable to find allocation");
+        TEST_RESULT_VOID(memFree(MEM_CONTEXT_ALLOC_BUFFER(memContextCurrent()->allocList[0])), "free allocation");
         TEST_RESULT_UINT(memContextCurrent()->allocFreeIdx, 0, "check alloc free idx");
 
-        TEST_RESULT_VOID(memFree(memContextCurrent()->allocList[1].buffer), "free allocation");
+        TEST_RESULT_VOID(memFree(MEM_CONTEXT_ALLOC_BUFFER(memContextCurrent()->allocList[1])), "free allocation");
         TEST_RESULT_UINT(memContextCurrent()->allocFreeIdx, 0, "check alloc free idx");
 
         TEST_RESULT_VOID(memNew(3), "new allocation");
@@ -231,8 +219,14 @@ testRun(void)
         TEST_RESULT_VOID(memNew(3), "new allocation");
         TEST_RESULT_UINT(memContextCurrent()->allocFreeIdx, MEM_CONTEXT_ALLOC_INITIAL_SIZE + 3, "check alloc free idx");
 
-        TEST_ERROR(memFree(NULL), AssertError, "assertion 'buffer != NULL' failed");
-        TEST_ERROR(memFree((void *)0x01), AssertError, "unable to find allocation");
+        TEST_ERROR(
+            memFree(NULL), AssertError,
+            "assertion '((MemContextAlloc *)buffer - 1) != NULL"
+                " && ((MemContextAlloc *)buffer - 1) != MEM_CONTEXT_ALLOC_HEADER(NULL)"
+                " && ((MemContextAlloc *)buffer - 1)->allocIdx <"
+                " memContextStack[memContextCurrentStackIdx].memContext->allocListSize"
+                " && memContextStack[memContextCurrentStackIdx].memContext->allocList[((MemContextAlloc *)buffer - 1)->allocIdx]'"
+                " failed");
         memFree(buffer);
 
         memContextSwitch(memContextTop());
@@ -246,6 +240,7 @@ testRun(void)
             memContextCallbackSet(memContextTop(), testFree, NULL), AssertError, "top context may not have a callback");
 
         MemContext *memContext = memContextNew("test-callback");
+        memContextKeep();
         memContextCallbackSet(memContext, testFree, memContext);
         TEST_ERROR(
             memContextCallbackSet(memContext, testFree, memContext), AssertError,
@@ -260,7 +255,8 @@ testRun(void)
 
         // Now test with an error
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_ASSIGN(memContext, memContextNew("test-callback-error"), "new mem context");
+        memContext = memContextNew("test-callback-error");
+        TEST_RESULT_VOID(memContextKeep(), "keep mem context");
         testFreeThrow = true;
         TEST_RESULT_VOID(memContextCallbackSet(memContext, testFree, memContext), "    set callback");
         TEST_ERROR(memContextFree(memContext), AssertError, "error in callback");
@@ -272,38 +268,39 @@ testRun(void)
     {
         memContextSwitch(memContextTop());
         MemContext *memContext = memContextNew("test-block");
+        memContextKeep();
 
         // Check normal block
         MEM_CONTEXT_BEGIN(memContext)
         {
-            TEST_RESULT_STR(memContextName(memContextCurrent()), "test-block", "context is now test-block");
+            TEST_RESULT_Z(memContextName(memContextCurrent()), "test-block", "context is now test-block");
         }
         MEM_CONTEXT_END();
 
-        TEST_RESULT_STR(memContextName(memContextCurrent()), "TOP", "context is now top");
+        TEST_RESULT_Z(memContextName(memContextCurrent()), "TOP", "context is now top");
 
         // Check block that errors
         TEST_ERROR(
             MEM_CONTEXT_BEGIN(memContext)
             {
-                TEST_RESULT_STR(memContextName(memContextCurrent()), "test-block", "context is now test-block");
+                TEST_RESULT_Z(memContextName(memContextCurrent()), "test-block", "context is now test-block");
                 THROW(AssertError, "error in test block");
             }
             MEM_CONTEXT_END(),
             AssertError, "error in test block");
 
-        TEST_RESULT_STR(memContextName(memContextCurrent()), "TOP", "context is now top");
+        TEST_RESULT_Z(memContextName(memContextCurrent()), "TOP", "context is now top");
 
         // Reset temp mem context after a single interaction
         // -------------------------------------------------------------------------------------------------------------------------
         MEM_CONTEXT_TEMP_RESET_BEGIN()
         {
-            TEST_RESULT_BOOL(MEM_CONTEXT_TEMP()->allocList[0].active, false, "nothing allocated");
+            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList[0], NULL, "nothing allocated");
             memNew(99);
-            TEST_RESULT_BOOL(MEM_CONTEXT_TEMP()->allocList[0].active, true, "1 allocation");
+            TEST_RESULT_PTR_NE(MEM_CONTEXT_TEMP()->allocList[0], NULL, "1 allocation");
 
             MEM_CONTEXT_TEMP_RESET(1);
-            TEST_RESULT_BOOL(MEM_CONTEXT_TEMP()->allocList[0].active, false, "nothing allocated");
+            TEST_RESULT_PTR(MEM_CONTEXT_TEMP()->allocList[0], NULL, "nothing allocated");
         }
         MEM_CONTEXT_TEMP_END();
     }
@@ -316,14 +313,17 @@ testRun(void)
         const char *memContextTestName = "test-new-block";
         MemContext *memContext = NULL;
 
+        TEST_RESULT_PTR(memContextCurrent(), memContextTop(), "context is now 'TOP'");
+
         MEM_CONTEXT_NEW_BEGIN(memContextTestName)
         {
             memContext = MEM_CONTEXT_NEW();
             TEST_RESULT_PTR(memContext, memContextCurrent(), "new mem context is current");
-            TEST_RESULT_STR(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
+            TEST_RESULT_Z(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
         }
         MEM_CONTEXT_NEW_END();
 
+        TEST_RESULT_Z(memContextName(memContextCurrent()), "TOP", "context name is now 'TOP'");
         TEST_RESULT_PTR(memContextCurrent(), memContextTop(), "context is now 'TOP'");
         TEST_RESULT_BOOL(memContext->state == memContextStateActive, true, "new mem context is still active");
         memContextFree(memContext);
@@ -338,7 +338,7 @@ testRun(void)
             MEM_CONTEXT_NEW_BEGIN(memContextTestName)
             {
                 memContext = MEM_CONTEXT_NEW();
-                TEST_RESULT_STR(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
+                TEST_RESULT_Z(memContextName(memContext), memContextTestName, "context is now '%s'", memContextTestName);
                 THROW(AssertError, "create failed");
             }
             MEM_CONTEXT_NEW_END();
@@ -370,6 +370,7 @@ testRun(void)
             MEM_CONTEXT_TEMP_BEGIN()
             {
                 memContextNew("not-to-be-moved");
+                memContextKeep();
 
                 MEM_CONTEXT_NEW_BEGIN("inner")
                 {
@@ -378,17 +379,17 @@ testRun(void)
                 }
                 MEM_CONTEXT_NEW_END();
 
-                TEST_RESULT_PTR(memContext->allocList[0].buffer, mem, "check memory allocation");
+                TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_BUFFER(memContext->allocList[0]), mem, "check memory allocation");
                 TEST_RESULT_PTR(memContextCurrent()->contextChildList[1], memContext, "check memory context");
 
                 // Null out the mem context in the parent so the move will fail
                 memContextCurrent()->contextChildList[1] = NULL;
-                TEST_ERROR(memContextMove(memContext, MEM_CONTEXT_OLD()), AssertError, "unable to find mem context in old parent");
+                TEST_ERROR(memContextMove(memContext, memContextPrior()), AssertError, "unable to find mem context in old parent");
 
                 // Set it back so the move will succeed
                 memContextCurrent()->contextChildList[1] = memContext;
-                TEST_RESULT_VOID(memContextMove(memContext, MEM_CONTEXT_OLD()), "move context");
-                TEST_RESULT_VOID(memContextMove(memContext, MEM_CONTEXT_OLD()), "move context again");
+                TEST_RESULT_VOID(memContextMove(memContext, memContextPrior()), "move context");
+                TEST_RESULT_VOID(memContextMove(memContext, memContextPrior()), "move context again");
 
                 // Move another context
                 MEM_CONTEXT_NEW_BEGIN("inner2")
@@ -398,14 +399,14 @@ testRun(void)
                 }
                 MEM_CONTEXT_NEW_END();
 
-                TEST_RESULT_VOID(memContextMove(memContext2, MEM_CONTEXT_OLD()), "move context");
+                TEST_RESULT_VOID(memContextMove(memContext2, memContextPrior()), "move context");
             }
             MEM_CONTEXT_TEMP_END();
 
-            TEST_RESULT_PTR(memContext->allocList[0].buffer, mem, "check memory allocation");
+            TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_BUFFER(memContext->allocList[0]), mem, "check memory allocation");
             TEST_RESULT_PTR(memContextCurrent()->contextChildList[1], memContext, "check memory context");
 
-            TEST_RESULT_PTR(memContext2->allocList[0].buffer, mem2, "check memory allocation 2");
+            TEST_RESULT_PTR(MEM_CONTEXT_ALLOC_BUFFER(memContext2->allocList[0]), mem2, "check memory allocation 2");
             TEST_RESULT_PTR(memContextCurrent()->contextChildList[2], memContext2, "check memory context 2");
         }
         MEM_CONTEXT_NEW_END();
