@@ -41,9 +41,9 @@ testRun(void)
         TEST_ERROR(jsonToStr(strNew("nullz")), JsonFormatError, "unexpected characters after string at 'z'");
 
         TEST_RESULT_PTR(jsonToStr(strNew("null")), NULL, "null string");
-        TEST_RESULT_STR(strPtr(jsonToStr(strNew(" \"test\""))), "test", "simple string");
-        TEST_RESULT_STR(strPtr(jsonToStr(strNew("\"te\\\"st\" "))), "te\"st", "string with quote");
-        TEST_RESULT_STR(strPtr(jsonToStr(strNew("\"\\\"\\\\\\/\\b\\n\\r\\t\\f\""))), "\"\\/\b\n\r\t\f", "string with escapes");
+        TEST_RESULT_STR_Z(jsonToStr(strNew(" \"test\"")), "test", "simple string");
+        TEST_RESULT_STR_Z(jsonToStr(strNew("\"te\\\"st\" ")), "te\"st", "string with quote");
+        TEST_RESULT_STR_Z(jsonToStr(strNew("\"\\\"\\\\\\/\\b\\n\\r\\t\\f\"")), "\"\\/\b\n\r\t\f", "string with escapes");
     }
 
     // *****************************************************************************************************************************
@@ -59,7 +59,7 @@ testRun(void)
         TEST_ASSIGN(kv, jsonToKv(strNew("{\"key1\": 747, \"key2\":\"value2\",\"key3\"\t:\t[\t] }")), "object");
         TEST_RESULT_UINT(varLstSize(kvKeyList(kv)), 3, "check key total");
         TEST_RESULT_UINT(varUInt64(kvGet(kv, varNewStr(strNew("key1")))), 747, "check object uint");
-        TEST_RESULT_STR(strPtr(varStr(kvGet(kv, varNewStr(strNew("key2"))))), "value2", "check object str");
+        TEST_RESULT_STR_Z(varStr(kvGet(kv, varNewStr(strNew("key2")))), "value2", "check object str");
         TEST_RESULT_UINT(varLstSize(varVarLst(kvGet(kv, varNewStr(strNew("key3"))))), 0, "check empty array");
 
         TEST_ASSIGN(kv, jsonToKv(strNew("\t{\n} ")), "empty object");
@@ -74,10 +74,9 @@ testRun(void)
         TEST_ERROR(jsonToVar(strNew("z")), JsonFormatError, "invalid type at 'z'");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(strPtr(varStr(jsonToVar(strNew(" \"test\"")))), "test", "simple string");
-        TEST_RESULT_STR(strPtr(varStr(jsonToVar(strNew("\"te\\\"st\" ")))), "te\"st", "string with quote");
-        TEST_RESULT_STR(
-            strPtr(varStr(jsonToVar(strNew("\"\\\"\\\\\\/\\b\\n\\r\\t\\f\"")))), "\"\\/\b\n\r\t\f", "string with escapes");
+        TEST_RESULT_STR_Z(varStr(jsonToVar(strNew(" \"test\""))), "test", "simple string");
+        TEST_RESULT_STR_Z(varStr(jsonToVar(strNew("\"te\\\"st\" "))), "te\"st", "string with quote");
+        TEST_RESULT_STR_Z(varStr(jsonToVar(strNew("\"\\\"\\\\\\/\\b\\n\\r\\t\\f\""))), "\"\\/\b\n\r\t\f", "string with escapes");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_ERROR(jsonToVar(strNew("ton")), JsonFormatError, "expected boolean at 'ton'");
@@ -94,8 +93,8 @@ testRun(void)
         VariantList *valueList = NULL;
         TEST_ASSIGN(valueList, varVarLst(jsonToVar(strNew("[1, \"test\", false]"))), "array");
         TEST_RESULT_UINT(varLstSize(valueList), 3, "check array size");
-        TEST_RESULT_INT(varUInt64(varLstGet(valueList, 0)), 1, "check array int");
-        TEST_RESULT_STR(strPtr(varStr(varLstGet(valueList, 1))), "test", "check array str");
+        TEST_RESULT_UINT(varUInt64(varLstGet(valueList, 0)), 1, "check array int");
+        TEST_RESULT_STR_Z(varStr(varLstGet(valueList, 1)), "test", "check array str");
         TEST_RESULT_BOOL(varBool(varLstGet(valueList, 2)), false, "check array bool");
 
         TEST_ASSIGN(valueList, varVarLst(jsonToVar(strNew("[ ]"))), "empty array");
@@ -114,32 +113,31 @@ testRun(void)
         TEST_ERROR(jsonToVarLst(strNew("[")), JsonFormatError, "expected data");
         TEST_ERROR(jsonToVarLst(strNew(" [] ZZZ")), JsonFormatError, "unexpected characters after array at 'ZZZ'");
 
-        TEST_RESULT_STR(
-            strPtr(strLstJoin(strLstNewVarLst(jsonToVarLst(strNew("[\"e1\", \"e2\"]"))), "|")), "e1|e2", "json list");
+        TEST_RESULT_STR_Z(strLstJoin(strLstNewVarLst(jsonToVarLst(strNew("[\"e1\", \"e2\"]"))), "|"), "e1|e2", "json list");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("jsonFromBool()"))
     {
-        TEST_RESULT_STR(strPtr(jsonFromBool(true)), "true", "json bool true");
-        TEST_RESULT_STR(strPtr(jsonFromBool(false)), "false", "json bool true");
+        TEST_RESULT_STR_Z(jsonFromBool(true), "true", "json bool true");
+        TEST_RESULT_STR_Z(jsonFromBool(false), "false", "json bool true");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("jsonFromInt(), jsonFromInt64(), jsonFromUInt() and jsonFromUInt64()"))
     {
-        TEST_RESULT_STR(strPtr(jsonFromInt(-2147483648)), "-2147483648", "json int");
-        TEST_RESULT_STR(strPtr(jsonFromInt64(-9223372036854775807L)), "-9223372036854775807", "json int64");
-        TEST_RESULT_STR(strPtr(jsonFromUInt(4294967295)), "4294967295", "json uint");
-        TEST_RESULT_STR(strPtr(jsonFromUInt64(18446744073709551615UL)), "18446744073709551615", "json uint64");
+        TEST_RESULT_STR_Z(jsonFromInt(-2147483648), "-2147483648", "json int");
+        TEST_RESULT_STR_Z(jsonFromInt64(-9223372036854775807L), "-9223372036854775807", "json int64");
+        TEST_RESULT_STR_Z(jsonFromUInt(4294967295), "4294967295", "json uint");
+        TEST_RESULT_STR_Z(jsonFromUInt64(18446744073709551615UL), "18446744073709551615", "json uint64");
     }
 
     // *****************************************************************************************************************************
     if (testBegin("jsonFromStr() and jsonFromStrInternal()"))
     {
-        TEST_RESULT_STR(strPtr(jsonFromStr(NULL)), "null", "null string");
-        TEST_RESULT_STR(strPtr(jsonFromStr(strNew("simple string"))), "\"simple string\"", "simple string");
-        TEST_RESULT_STR(strPtr(jsonFromStr(strNew("\"\\/\b\n\r\t\f"))), "\"\\\"\\\\/\\b\\n\\r\\t\\f\"", "string escapes");
+        TEST_RESULT_STR_Z(jsonFromStr(NULL), "null", "null string");
+        TEST_RESULT_STR_Z(jsonFromStr(strNew("simple string")), "\"simple string\"", "simple string");
+        TEST_RESULT_STR_Z(jsonFromStr(strNew("\"\\/\b\n\r\t\f")), "\"\\\"\\\\/\\b\\n\\r\\t\\f\"", "string escapes");
     }
 
     // *****************************************************************************************************************************
@@ -149,11 +147,11 @@ testRun(void)
         String *json = NULL;
 
         TEST_ASSIGN(json, jsonFromKv(keyValue), "kvToJson - empty");
-        TEST_RESULT_STR(strPtr(json), "{}", "  empty curly brackets");
+        TEST_RESULT_STR_Z(json, "{}", "  empty curly brackets");
 
         kvPut(keyValue, varNewStrZ("backup"), varNewVarLst(varLstNew()));
         TEST_ASSIGN(json, jsonFromKv(keyValue), "kvToJson - kv with empty array");
-        TEST_RESULT_STR(strPtr(json), "{\"backup\":[]}", "  kv with empty array brackets");
+        TEST_RESULT_STR_Z(json, "{\"backup\":[]}", "  kv with empty array brackets");
 
         kvPutKv(keyValue, varNewStr(strNew("archive")));
         kvPutKv(keyValue, varNewStr(strNew("empty")));
@@ -172,8 +170,8 @@ testRun(void)
         kvPut(keyValue, varNewStrZ("null-list"), varNewVarLst(NULL));
 
         TEST_ASSIGN(json, jsonFromKv(keyValue), "kvToJson - kv with empty array, kv, varList with values");
-        TEST_RESULT_STR(
-            strPtr(json),
+        TEST_RESULT_STR_Z(
+            json,
             "{"
                 "\"archive\":{},"
                 "\"backup\":[],"
@@ -190,7 +188,8 @@ testRun(void)
                 "\"empty\":{},"
                 "\"null-list\":null,"
                 "\"null-str\":null"
-            "}", "  kv with empty array, kv, varList with values");
+            "}",
+            "  kv with empty array, kv, varList with values");
 
         TEST_ASSIGN(
             keyValue,
@@ -202,7 +201,8 @@ testRun(void)
                     "\"checksum-page-error\":[1,[4,6]],\"backup-timestamp-start\":1482182951}"))),
             "multiple values with array");
         TEST_ASSIGN(json, jsonFromKv(keyValue), "  kvToJson - sorted");
-        TEST_RESULT_STR(strPtr(json),
+        TEST_RESULT_STR_Z(
+            json,
             "{\"backup-info-size-delta\":1982702,\"backup-prior\":\"20161219-212741F_20161219-212803I\","
             "\"backup-reference\":[\"20161219-212741F\",\"20161219-212741F_20161219-212803I\"],"
             "\"backup-timestamp-start\":1482182951,\"checksum-page-error\":[1,[4,6]]}",
@@ -243,7 +243,8 @@ testRun(void)
         kvAdd(sectionKv, varNewStr(strNew("escape")), varNewStr(strNew("\"\\/\b\n\r\t\f")));
 
         TEST_ASSIGN(json, jsonFromVar(keyValue), "KeyValue");
-        TEST_RESULT_STR(strPtr(json),
+        TEST_RESULT_STR_Z(
+            json,
             "{\"backup-info-size-delta\":1982702,\"backup-prior\":\"20161219-212741F_20161219-212803I\","
             "\"backup-reference\":[\"20161219-212741F\",\"20161219-212741F_20161219-212803I\",null],"
             "\"backup-timestamp-start\":1482182951,\"checksum-page-error\":[1],"
@@ -254,7 +255,7 @@ testRun(void)
         Variant *varListOuter = NULL;
 
         TEST_ASSIGN(json, jsonFromVar(varNewVarLst(varLstNew())), "VariantList");
-        TEST_RESULT_STR(strPtr(json), "[]", "  empty list no pretty print");
+        TEST_RESULT_STR_Z(json, "[]", "  empty list no pretty print");
 
         TEST_ASSIGN(varListOuter, varNewVarLst(varLstNew()), "new variant list with keyValues");
         varLstAdd(varVarLst(varListOuter), varNewStrZ("ASTRING"));
@@ -266,7 +267,8 @@ testRun(void)
         varLstAdd(varVarLst(varListOuter), keyValue);
 
         TEST_ASSIGN(json, jsonFromVar(varListOuter), "VariantList");
-        TEST_RESULT_STR(strPtr(json),
+        TEST_RESULT_STR_Z(
+            json,
             "[\"ASTRING\",9223372036854775807,2147483647,true,[],null,{\"backup-info-size-delta\":1982702,"
             "\"backup-prior\":\"20161219-212741F_20161219-212803I\","
             "\"backup-reference\":[\"20161219-212741F\",\"20161219-212741F_20161219-212803I\",null],"
@@ -278,7 +280,8 @@ testRun(void)
         varLstAdd(varVarLst(varListOuter), keyValue2);
 
         TEST_ASSIGN(json, jsonFromVar(varListOuter), "VariantList - multiple elements");
-        TEST_RESULT_STR(strPtr(json),
+        TEST_RESULT_STR_Z(
+            json,
             "[\"ASTRING\",9223372036854775807,2147483647,true,[],null,{\"backup-info-size-delta\":1982702,"
             "\"backup-prior\":\"20161219-212741F_20161219-212803I\","
             "\"backup-reference\":[\"20161219-212741F\",\"20161219-212741F_20161219-212803I\",null],"
@@ -294,14 +297,14 @@ testRun(void)
         varLstAdd(varList, varNewUInt(32));
         varLstAdd(varList, varNewUInt64(10000000000));
 
-        TEST_RESULT_STR(strPtr(jsonFromVar(varNewVarLst(varList))), "[32,10000000000]", "list various types");
+        TEST_RESULT_STR_Z(jsonFromVar(varNewVarLst(varList)), "[32,10000000000]", "list various types");
 
         //--------------------------------------------------------------------------------------------------------------------------
-        TEST_RESULT_STR(strPtr(jsonFromVar(NULL)), "null", "null variant");
-        TEST_RESULT_STR(strPtr(jsonFromVar(varNewBool(true))), "true", "bool variant");
-        TEST_RESULT_STR(strPtr(jsonFromVar(varNewUInt(66))), "66", "uint variant");
-        TEST_RESULT_STR(strPtr(jsonFromVar(varNewUInt64(10000000001))), "10000000001", "uint64 variant");
-        TEST_RESULT_STR(strPtr(jsonFromVar(varNewStrZ("test \" string"))), "\"test \\\" string\"", "string variant");
+        TEST_RESULT_STR_Z(jsonFromVar(NULL), "null", "null variant");
+        TEST_RESULT_STR_Z(jsonFromVar(varNewBool(true)), "true", "bool variant");
+        TEST_RESULT_STR_Z(jsonFromVar(varNewUInt(66)), "66", "uint variant");
+        TEST_RESULT_STR_Z(jsonFromVar(varNewUInt64(10000000001)), "10000000001", "uint64 variant");
+        TEST_RESULT_STR_Z(jsonFromVar(varNewStrZ("test \" string")), "\"test \\\" string\"", "string variant");
     }
 
     FUNCTION_HARNESS_RESULT_VOID();
