@@ -16,8 +16,7 @@ void
 testRun(void)
 {
     // Create default storage object for testing
-    Storage *storageTest = storagePosixNew(
-        strNew(testPath()), STORAGE_MODE_FILE_DEFAULT, STORAGE_MODE_PATH_DEFAULT, true, NULL);
+    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
 
     // *****************************************************************************************************************************
     if (testBegin("InfoBackup"))
@@ -466,7 +465,7 @@ testRun(void)
             "option-archive-check=true\n"
             "option-archive-copy=false\n"
             "option-backup-standby=false\n"
-            "option-buffer-size=4194304\n"
+            "option-buffer-size=1048576\n"
             "option-checksum-page=false\n"
             "option-compress=true\n"
             "option-compress-level=6\n"
